function Hst=distribute(XY,Hst,BinsX,DataInclude,Crit)
%distribute - this function distributes values from XY(2,:) vector according to XY(1,:) position
%into Hst vector if they satisfy XY(3,:)=Crit criterion
%(adds new counts to values, xeisting in Hst), according to beans vectors
%Output:
%Hst -	Output historgam matrix.

%Inputs:
%XY - 	3xN Data matrix. XY(1,:) - position value; XY(2,:) - weight value; XY(3,:) - criterion value
%Hst -	Input historgam matrix.
%BinsX -	Calculated or provided X bins' boundaries vector.
%DataInclude	- Select data to include into the calculation - all the data <1>*, positive <2>, negative <3>
%Crit -	Criterion for including the point into consideration


SizeX=length(Hst);	%Length of hystogram file

PointX=fix(SizeX/2); %Initial positions of latest bin coordinate


%---------Determining bins analysis range
BegCycle=1;
EndCycle=size(XY,2);	%Length of XY data matrix

for i=BegCycle:EndCycle	%Cycle through XY data matrix
	
	GoCrit=0;
	
	switch Crit	%Criterion for including the point into consideration
	case 1	%Outer
	    if XY(3,i)==1; GoCrit=1;	end
	case 2	%inner
	    if XY(3,i)==-1; GoCrit=1;	end
	case 3	%all
	    GoCrit=1;
	end
	
	GoData=0; 
	switch DataInclude	%Criterion by data value for including the point into consideration
	case 1	%all
	    GoData=1;
	case 2	%Outer
	    if XY(2,i)>0; GoData=1;	end
	case 3	%inner
	    if XY(2,i)<0; GoData=1;	end
	end

	
	if GoCrit==1&GoData==1  %the point satisfies the criterion and data satisfies data condition
		
		%** X binning
		if XY(1,i)<BinsX(PointX+1)	%Moving down through the bins
			while PointX>0	%we are above the lowest bin boundary
				if XY(1,i)>=BinsX(PointX)	%fit in the current bin
					break
				else
					PointX=PointX-1;	%1 step down
				end
			end
		else	%Moving up through the bins
			PointX=PointX+1;	%1 step up
			while PointX<=SizeX	%we are below the topmost bin boundary
				if XY(1,i)<BinsX(PointX+1)	%fit in the current bin
					break
				else
					PointX=PointX+1;	%1 step up
				end
			end
		end
		
		%** Adding 1 count to histogram bin
		if (PointX>0)&(PointX<=SizeX)	%Point coordinate is within hisogram vector range
			Hst(PointX)=Hst(PointX)+XY(2,i);
		end
		PointX=max(1,min(SizeX,PointX));	%Limiting the maximum value
	end
end

