function [dev,ecount_L]=equal_dist2line_est(par_val,ecount_L,minimize_dist)
%Function estimating how far from equal are distances from all the points with X Y Z coordinates
%from the orientation line defined by par_val coordinates of 2 points.
%The more non-uniform distances are - the higher output dev is.
%Inputs:
%par_val	- parameter values, 6 coordinates of 2 points defining orientation line
%ecount_L	- initial number of functions count - will be increased by 1
%minimize_dist	- flag to minimize distance to the line in addition to std

%Output:
%dev	- standard deviation of all the distances of X Y Z to the orientation line

global ATOM X Y Z
if nargin==2
	minimize_dist=1;
end
ecount_L=ecount_L+1;


%Line coefficients and initial point
X0=par_val(1);
Y0=par_val(2);
Z0=par_val(3);

a=(par_val(4)-X0);
b=(par_val(5)-Y0);
c=(par_val(6)-Z0);

%Calculating matrix of distances
for i=1:length(X)
	L(i)=((((Y(i)-Y0)*c-(Z(i)-Z0)*b)^2+((Z(i)-Z0)*a-(X(i)-X0)*c)^2+((X(i)-X0)*b-(Y(i)-Y0)*a)^2)/...
		(a^2+b^2+c^2))^0.5;	%distance between the current point and line
end

if minimize_dist==1
	dev=std(L)*mean(L);
else
	dev=std(L);
end
%mean(L)