function [F]=genz(a,b,Sigma)

%June 1999 M.Matei  matei@univ-lille1.fr
%LAIL University Lille1 France

%Computes normal multivariate probability by Genz' algorithm.
%Ref: Numerical computation of multivariate Normal Probabilities
%     A.Genz, 1992
%----------------------------------------------------------------
%     F(a,b;Sigma)=int f(y;Sigma) dy
%The dimension is of the integral is n.
%Integration limits are respectively minus a and b
%and their dimension is n.
%The function f(y,Sigma) is the normal central density of vector y with 
%covariance matrix Sigma positive definite.
%Returns:   F-probability value.

%This function needs intgc.m


%Cholesky decomposition of the Covariance matrix
%Warning: covariance should be positive definite!!!

C=chol(Sigma); 

adv=[];

intsum=0;
N=0;varsum=0;
ee=0.001;
Nmax=7;         %number of iterations of the Monte Carlo algorithm: the integral
                %converge very fast to its true value
                %so Nmax don't need to be elevate.
erreur=0.1;
alpha=2.5;      %for Monte Carlo integration
m=length(a);
nbp=360; 	%Increase number of samples if you want higher accuracy.
				%In this cas speed decreases rapidly.

%constant limits of integration

d(1)=intgc(nbp,floor(a(1)/C(1,1)));
e(1)=intgc(nbp,floor(b(1)/C(1,1)));
f(1)=e(1)-d(1);


%the integration uses the Monte Carlo algorithm

while (N<Nmax) | erreur>ee

for i=1:m-1
		%generate random values to compute constant limit for integration
	
		W(i)=random('unif',0,1);
	end

	for i=2:m
		%transformate integration limits
		y(i)=norminv(normcdf(d(i-1)+W(i-1)*(e(i-1)-d(i-1)),0,1),0,1);
		s(1)=0;
			for j=1:i-1			
				s(j+1)=s(j)+C(i,j)*y(j);
			end
		[ms,ns]=size(s);
		
		%compute constant limits		

		d(i)=intgc(nbp,(a(i)-s(1,ns))/C(i,i));
		e(i)=intgc(nbp,(b(i)-s(1,ns))/C(i,i));
		f(i)=(e(i)-d(i))*f(i-1);
	end
	
	intsum=intsum+f(m);
	varsum=varsum+f(m)^2;
	N=N+1;
	%compute Monte Carlo integration error
	erreur=alpha*sqrt(abs((varsum/N-(intsum/N)^2)/N));

end

F=intsum/N;

