function pdbadcol(s,DestFileType,SrcFile,SrcFileType,DataType,DataOligo,SrcColn,DestColn,SrcDir,DestDir)
%pdbadcol program for introducing column with data from text or pdb file into destination PDB file.
%INPUTS:
%s	- cell array with filenames
%DestFileType	- PDB file format
%SrcFile	- source file
%SrcFileType	- Source file format
%DataType	- Data type (per residue, per atom) in source file
%DataOligo	- Data per monomer or per whole oligomer in source file
%SrcColn	- Source column with data
%DestColn	- Destination column for data
%
%Output
%
global ATOM

dbstop if error

SrcFile_array=SrcFile;%Remembering array of names
if ~isempty(s)
	if ~iscell(SrcFile_array)|(length(SrcFile_array)==1)	%there is one input file
		if ~iscell(SrcFile_array)
			SrcFile=SrcFile_array;
		else
			SrcFile=SrcFile_array{1};
		end
		ATOM0=[];
		%============ATOM array initialization
		ATOM0.line=[];	%Number of the line in PDB file
		ATOM0.index=[];	%        Atom serial number.
		ATOM0.name={};	%          Atom name.
		ATOM0.altloc={};	%        Alternate location indicator.
		ATOM0.resname={};	%       Residue name.
		ATOM0.chain={};	%       Chain identifier.
		ATOM0.resid=[];	%        Residue sequence number.
		ATOM0.icode={};	%         Code for insertion of residues.
		ATOM0.x=[];	%             Orthogonal coordinates for X in Angstroms.
		ATOM0.y=[];	%             Orthogonal coordinates for Y in Angstroms.
		ATOM0.z=[];	%             Orthogonal coordinates for Z in Angstroms.
		ATOM0.occupancy=[];	%     Occupancy.
		ATOM0.beta=[];	%    Temperature factor.
		ATOM0.segname={};	%         Segment identifier, left-justified.
		ATOM0.element={};	%       Element symbol, right-justified.
		ATOM0.charge={};	%        Charge on the atom.
		ATOM0.pdb=[];	%content of the PDB file
		
		%     Fields(1)=0;%        Atom serial number.
		%     Fields(2)=0; %          Atom name.
		%     Fields(3)=0; %        Alternate location indicator.
		%     Fields(4)=0; %       Residue name.
		%     Fields(5)=0; %       Chain identifier.
		%     Fields(6)=0; %        Residue sequence number.
		%     Fields(7)=0; %         Code for insertion of residues.
		%     Fields(8)=0; %             Orthogonal coordinates for X in Angstroms.
		%     Fields(9)=0; %             Orthogonal coordinates for Y in Angstroms.
		%     Fields(10)=1; %             Orthogonal coordinates for Z in Angstroms.
		%     Fields(11)=1; %     Occupancy.
		%     Fields(12)=1; %    Temperature factor.
		%     Fields(13)=0; %         Segment identifier, left-justified.
		%     Fields(14)=0; %       Element symbol, right-justified.
		%     Fields(15)=0; %        Charge on the atom.
		Fields=ones(1,15);    
		
		
		cd(SrcDir)
		%=================Reading source data from the file
		switch SrcFileType
		case 1	%PDB
			ATOMSrc=ATOM0;
			ATOMSrc=readPDBfull(SrcFile,Fields,1);	%=================Reads PDB structure file into structure array
			ProgressBarFile(m);
			disp(['Data to insert. ',SrcFile,':      ',num2str(length(ATOMSrc.line)), '-atoms structure read']);
			
			switch SrcColn	%Select column in ATOMSrc to read insert data
				% 	switch DestColn	%Select column in ATOMSrc to read insert data
			case 1
				DataIns=ATOMSrc.index;	%        Atom serial number.
			case 2
				DataIns=ATOMSrc.name;	%          Atom name.
			case 3
				DataIns=ATOMSrc.altloc;	%        Alternate location indicator.
			case 4
				DataIns=ATOMSrc.resname;	%       Residue name.
			case 5
				DataIns=ATOMSrc.chain;	%       Chain identifier.
			case 6
				DataIns=ATOMSrc.resid;	%        Residue sequence number.
			case 7
				DataIns=ATOMSrc.icode;	%         Code for insertion of residues.
			case 8
				DataIns=ATOMSrc.x;	%             Orthogonal coordinates for X in Angstroms.
			case 9
				DataIns=ATOMSrc.y;	%             Orthogonal coordinates for Y in Angstroms.
			case 10
				DataIns=ATOMSrc.z;	%             Orthogonal coordinates for Z in Angstroms.
			case 11
				DataIns=ATOMSrc.occupancy;	%     Occupancy.
			case 12
				DataIns=ATOMSrc.beta;	%    Temperature factor.
			case 13
				DataIns=ATOMSrc.segname;	%         Segment identifier, left-justified.
			case 14
				DataIns=ATOMSrc.element;	%       Element symbol, right-justified.
			case 15
				DataIns=ATOMSrc.charge;	%        Charge on the atom.
			end
			ATOMSrc=[];
		case 2	%TXT column
			DataIns=load(SrcFile, '-ascii')';
		case 3	%TXT GETAREA
			ATOMSrc=[];
			ATOMSrc=readGETAREAfull(SrcFile,DataType);
			DataIns=ATOMSrc.energy;
			ATOMSrc=[];
		case 4	%other
			DataIns=load(SrcFile, '-ascii')';
		case 5	%'*.txt profile' - profile of some value along channel axis. 1st line - name of columns, will not be read
			CombProf=[];
			tCombProf=[];
			tCombProf=textread(SrcFile,'%f','delimiter','\n','headerlines',1);
			tCombProf=reshape(tCombProf,2,floor(length(tCombProf)/2))';
			CombMBinsZ=tCombProf(:,1);	%column with position values
			disp(['Profile for combining: ',SrcFile,':      ',num2str(length(CombMBinsZ)),...
					'-bins file read']);
			SndNp(2);
			CombProf=tCombProf(:,2)';
			DataType=2;	%Per atom 
			DataOligo=2;	%Per whole oligomer
		end
		
		ATOMInsProcessed=0;	%ATOMIns not formed yet
	end	%there is one input file
	
	for m=1:length(s)
		if iscell(SrcFile_array)	%there are many input files
			SrcFile=SrcFile_array{m};
			ATOM0=[];
			%============ATOM array initialization
			ATOM0.line=[];	%Number of the line in PDB file
			ATOM0.index=[];	%        Atom serial number.
			ATOM0.name={};	%          Atom name.
			ATOM0.altloc={};	%        Alternate location indicator.
			ATOM0.resname={};	%       Residue name.
			ATOM0.chain={};	%       Chain identifier.
			ATOM0.resid=[];	%        Residue sequence number.
			ATOM0.icode={};	%         Code for insertion of residues.
			ATOM0.x=[];	%             Orthogonal coordinates for X in Angstroms.
			ATOM0.y=[];	%             Orthogonal coordinates for Y in Angstroms.
			ATOM0.z=[];	%             Orthogonal coordinates for Z in Angstroms.
			ATOM0.occupancy=[];	%     Occupancy.
			ATOM0.beta=[];	%    Temperature factor.
			ATOM0.segname={};	%         Segment identifier, left-justified.
			ATOM0.element={};	%       Element symbol, right-justified.
			ATOM0.charge={};	%        Charge on the atom.
			ATOM0.pdb=[];	%content of the PDB file
			
			%     Fields(1)=0;%        Atom serial number.
			%     Fields(2)=0; %          Atom name.
			%     Fields(3)=0; %        Alternate location indicator.
			%     Fields(4)=0; %       Residue name.
			%     Fields(5)=0; %       Chain identifier.
			%     Fields(6)=0; %        Residue sequence number.
			%     Fields(7)=0; %         Code for insertion of residues.
			%     Fields(8)=0; %             Orthogonal coordinates for X in Angstroms.
			%     Fields(9)=0; %             Orthogonal coordinates for Y in Angstroms.
			%     Fields(10)=1; %             Orthogonal coordinates for Z in Angstroms.
			%     Fields(11)=1; %     Occupancy.
			%     Fields(12)=1; %    Temperature factor.
			%     Fields(13)=0; %         Segment identifier, left-justified.
			%     Fields(14)=0; %       Element symbol, right-justified.
			%     Fields(15)=0; %        Charge on the atom.
			Fields=ones(1,15);    
			
			
			cd(SrcDir)
			%=================Reading source data from the file
			switch SrcFileType
			case 1	%PDB
				ATOMSrc=ATOM0;
				ATOMSrc=readPDBfull(SrcFile,Fields,1);	%=================Reads PDB structure file into structure array
				disp(['Data to insert. ',SrcFile,':      ',num2str(length(ATOMSrc.line)), '-atoms structure read']);
				
				switch SrcColn	%Select column in ATOMSrc to read insert data
					% 	switch DestColn	%Select column in ATOMSrc to read insert data
				case 1
					DataIns=ATOMSrc.index;	%        Atom serial number.
				case 2
					DataIns=ATOMSrc.name;	%          Atom name.
				case 3
					DataIns=ATOMSrc.altloc;	%        Alternate location indicator.
				case 4
					DataIns=ATOMSrc.resname;	%       Residue name.
				case 5
					DataIns=ATOMSrc.chain;	%       Chain identifier.
				case 6
					DataIns=ATOMSrc.resid;	%        Residue sequence number.
				case 7
					DataIns=ATOMSrc.icode;	%         Code for insertion of residues.
				case 8
					DataIns=ATOMSrc.x;	%             Orthogonal coordinates for X in Angstroms.
				case 9
					DataIns=ATOMSrc.y;	%             Orthogonal coordinates for Y in Angstroms.
				case 10
					DataIns=ATOMSrc.z;	%             Orthogonal coordinates for Z in Angstroms.
				case 11
					DataIns=ATOMSrc.occupancy;	%     Occupancy.
				case 12
					DataIns=ATOMSrc.beta;	%    Temperature factor.
				case 13
					DataIns=ATOMSrc.segname;	%         Segment identifier, left-justified.
				case 14
					DataIns=ATOMSrc.element;	%       Element symbol, right-justified.
				case 15
					DataIns=ATOMSrc.charge;	%        Charge on the atom.
				end
				ATOMSrc=[];
			case 2	%TXT column
				DataIns=load(SrcFile, '-ascii')';
			case 3	%TXT GETAREA
				ATOMSrc=[];
				ATOMSrc=readGETAREAfull(SrcFile,DataType);
				DataIns=ATOMSrc.energy;
				ATOMSrc=[];
			case 4	%other
				DataIns=load(SrcFile, '-ascii')';
			case 5	%'*.txt profile' - profile of some value along channel axis. 1st line - name of columns, will not be read
				CombProf=[];
				tCombProf=[];
				tCombProf=textread(SrcFile,'%f','delimiter','\n','headerlines',1);
				tCombProf=reshape(tCombProf,2,floor(length(tCombProf)/2))';
				CombMBinsZ=tCombProf(:,1);	%column with position values
				disp(['Profile for combining: ',SrcFile,':      ',num2str(length(CombMBinsZ)),...
						'-bins file read']);
				SndNp(2);
				CombProf=tCombProf(:,2)';
				DataType=2;	%Per atom 
				DataOligo=2;	%Per whole oligomer
			end
			
			ATOMInsProcessed=0;	%ATOMIns not formed yet
		end	%there are many input files
		
		
		cd(DestDir)
		ATOM=[];
		ATOM=ATOM0;	%Initializing ATOM array
		ATOM=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
		disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM.line)), '-atoms structure read']);
		
		%DataType,DataOligo,SrcColn,DestColn
		
		
		if ~ATOMInsProcessed	%This is the first PDB in the set
			%--- calculate monomer length	- supposing that all monomers are of the same length
			FirsrResid=min(ATOM.resid);
			LastResid=max(ATOM.resid);
			% 		Monomer=LastResid-FirsrResid+1;	%number of residues in monomer
			OligoRes=1;	%All the residues in oligomer
			FirstAtoms=1;	%1st monomer begins
			for i=2:length(ATOM.resid)
				if ATOM.resid(i-1)>ATOM.resid(i)	%New monomer begins
					FirstAtoms(end+1)=i;
				end
				
				if ATOM.resid(i-1)~=ATOM.resid(i)	%New residue begins
					OligoRes(end+1)=i;
				end
			end
			Oligo=length(FirstAtoms);	%number of monomers in oligomer
			if Oligo>1	%Oligomer
				MonomerAtoms=FirstAtoms(2)-FirstAtoms(1);	%number of atoms in monomer
				Monomer=min(find(OligoRes==FirstAtoms(2)))-1;%number of residues in monomer
			else	%monomer
				MonomerAtoms=ATOM.index(end)-ATOM.index(1)+1;	%number of atoms in monomer
				Monomer=length(OligoRes);%number of residues in monomer
			end
			ATOMIns=[];
			
			
			%============== Forming data column to insert
			switch SrcFileType
			case 5	%'*.txt profile' - profile of some value along channel axis. 1st line - name of columns, will not be read
				MBinsZ=ATOM.z;	%Coordinates of atoms for reading interpolation from profile
				
				DataIns=interp1AGB(CombMBinsZ,CombProf,MBinsZ)';	%Interpolation from profile
			end
			
			switch DataType	%Data type (per residue, per atom) in source file
			case 1	%per residue
				if DataOligo==2 %per whole oligomer
					DataPosition=1;
					ATOMIns=insertATOMIns(ATOMIns,1,DataIns(DataPosition));
					
					% 				ATOM.resid
					%length(ATOM.resid)
					% 				DataIns
					%length(DataIns)
					for i=2:length(ATOM.resid)
						if ATOM.resid(i)~=ATOM.resid(i-1)	%next residue
							DataPosition=DataPosition+1;
						end
						ATOMIns=insertATOMIns(ATOMIns,i,DataIns(DataPosition));	%Insert data into the next residue
					end
				else	%per monomer
					DataOligo=2; %per whole oligomer
					j=FirstAtoms;	%index for the current position in all monomers simultaneously
					DataPosition=1;
					ATOMIns=insertATOMIns(ATOMIns,j,DataIns(DataPosition));
					
					for i=2:MonomerAtoms	%Moving along monomer
						j=FirstAtoms+i-1;	%index for the current position in all monomers simultaneously
						if ATOM.resid(i)~=ATOM.resid(i-1)	%next residue
							DataPosition=DataPosition+1;
							%disp([num2str(i),'     ',num2str(DataPosition)]);
							
						end
						ATOMIns=insertATOMIns(ATOMIns,j,DataIns(DataPosition));	%Insert data into the next residue
					end
				end
			case 2	%per atom
				ATOMIns=DataIns;
			end
			
			switch DataOligo	%Data per monomer or per whole oligomer in source file
			case 1	%per monomer
				for i=2:Oligo	%other monomers
					ATOMIns=[ATOMIns,ATOMIns(1:MonomerAtoms)];	%Duplicating data
				end
			case 2	%per whole oligomer
			end
			ATOMInsProcessed=1;
		end
		
		
		
		%==================  Insert final data into PDB
		switch DestColn	%Select column in ATOM to insert data
		case 1
			ATOM.index=ATOMIns;	%        Atom serial number.
		case 2
			ATOM.name=ATOMIns;	%          Atom name.
		case 3
			ATOM.altloc=ATOMIns;	%        Alternate location indicator.
		case 4
			ATOM.resname=ATOMIns;	%       Residue name.
		case 5
			ATOM.chain=ATOMIns;	%       Chain identifier.
		case 6
			ATOM.resid=ATOMIns;	%        Residue sequence number.
		case 7
			ATOM.icode=ATOMIns;	%         Code for insertion of residues.
		case 8
			ATOM.x=ATOMIns;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			ATOM.y=ATOMIns;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			ATOM.z=ATOMIns;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			ATOM.occupancy=ATOMIns;	%     Occupancy.
		case 12
			ATOM.beta=ATOMIns;	%    Temperature factor.
		case 13
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM.segname=ATOMIns;	%         Segment identifier, left-justified.
			elseif ischar(ATOMIns)	%char data
				ATOM.segname=cellstr(ATOMIns);	%         Segment identifier, left-justified.
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM.segname=cellstr(num2str(ATOMIns))';	%         Segment identifier, left-justified.
			end
		case 14
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM.element=ATOMIns;	%       Element symbol, right-justified
			elseif ischar(ATOMIns)	%char data
				ATOM.element=cellstr(ATOMIns);	%       Element symbol, right-justified
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM.element=cellstr(num2str(ATOMIns))';	%       Element symbol, right-justified
			end
		case 15
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM.charge=ATOMIns;	%        Charge on the atom
			elseif ischar(ATOMIns)	%char data
				ATOM.charge=cellstr(ATOMIns);	%        Charge on the atom
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM.charge=cellstr(num2str(ATOMIns))';	%        Charge on the atom
			end
		end
		
		writePDBfull([s{m},'_new.pdb'],ATOM,Fields,1);
		SndNp(2);
	end
	
	
	%beep;
	disp('Finished');
end





%_________________________________________

function insertATOMdata(DestColn,ATOMposition,DataIns)
global ATOM

for i=ATOMposition	%position in ATOM list
	switch DestColn	%Select column in ATOM to insert data
	case 1
		ATOM.index(i)=DataIns;	%        Atom serial number.
	case 2
		ATOM.name{i}=DataIns;	%          Atom name.
		
	case 3
		ATOM.altloc{i}=DataIns;	%        Alternate location indicator.
		
	case 4
		ATOM.resname{i}=DataIns;	%       Residue name.
		
	case 5
		ATOM.chain{i}=DataIns;	%       Chain identifier.
		
	case 6
		ATOM.resid(i)=DataIns;	%        Residue sequence number.
		
	case 7
		ATOM.icode{i}=DataIns;	%         Code for insertion of residues.
		
	case 8
		ATOM.x(i)=DataIns;	%             Orthogonal coordinates for X in Angstroms.
		
	case 9
		ATOM.y(i)=DataIns;	%             Orthogonal coordinates for Y in Angstroms.
		
	case 10
		ATOM.z(i)=DataIns;	%             Orthogonal coordinates for Z in Angstroms.
		
	case 11
		ATOM.occupancy(i)=DataIns;	%     Occupancy.
		
	case 12
		ATOM.beta(i)=DataIns;	%    Temperature factor.
		
	case 13
		ATOM.segname{i}=DataIns;	%         Segment identifier, left-justified.
		
	case 14
		ATOM.element{i}=DataIns;	%       Element symbol, right-justified.
		
	case 15
		ATOM.charge{i}=DataIns;	%        Charge on the atom.
	end
	
end


function ATOMIns=insertATOMIns(ATOMIns,ATOMposition,DataIns)
%Inserts single data value from DataIns into (multiple) ATOMIns position(s)

for i=ATOMposition	%position in ATOM list
	ATOMIns(i)=DataIns;
end