function pdbrenumres(s,DestFileType,DestColn,DestDir)	%Program for renumbering residues (or anything) in selected column
%INPUTS:
%s	- cell array with filenames
%DestFileType	- PDB file format
%DestColn	- Destination column for data
%DestDir	- Destination directory for data

%
%Output
%
%dbstop if error
global ATOM

if ~isempty(s)
    ATOM0=[];
    %============ATOM array initialization
    ATOM0.line=[];	%Number of the line in PDB file
    ATOM0.index=[];	%        Atom serial number.
    ATOM0.name={};	%          Atom name.
    ATOM0.altloc={};	%        Alternate location indicator.
    ATOM0.resname={};	%       Residue name.
    ATOM0.chain={};	%       Chain identifier.
    ATOM0.resid=[];	%        Residue sequence number.
    ATOM0.icode={};	%         Code for insertion of residues.
    ATOM0.x=[];	%             Orthogonal coordinates for X in Angstroms.
    ATOM0.y=[];	%             Orthogonal coordinates for Y in Angstroms.
    ATOM0.z=[];	%             Orthogonal coordinates for Z in Angstroms.
    ATOM0.occupancy=[];	%     Occupancy.
    ATOM0.beta=[];	%    Temperature factor.
    ATOM0.segname={};	%         Segment identifier, left-justified.
    ATOM0.element={};	%       Element symbol, right-justified.
    ATOM0.charge={};	%        Charge on the atom.
    ATOM0.pdb=[];	%content of the PDB file
    
    Fields=ones(1,15);    
    
    
    for m=1:length(s)
	cd(DestDir)
	ATOM=[];
	ATOM=ATOM0;	%Initializing ATOM array
	ATOM=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
	ProgressBarFile(m);
	disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM.line)), '-atoms structure read']);
	
	switch DestColn	%Select column in ATOMSrc to read insert data
	case 1
	    ATOMIns=ATOM.index;	%        Atom serial number.
	case 2
	    ATOMIns=ATOM.name;	%          Atom name.
	case 3
	    ATOMIns=ATOM.altloc;	%        Alternate location indicator.
	case 4
	    ATOMIns=ATOM.resname;	%       Residue name.
	case 5
	    ATOMIns=ATOM.chain;	%       Chain identifier.
	case 6
	    ATOMIns=ATOM.resid;	%        Residue sequence number.
	case 7
	    ATOMIns=ATOM.icode;	%         Code for insertion of residues.
	case 8
	    ATOMIns=ATOM.x;	%             Orthogonal coordinates for X in Angstroms.
	case 9
	    ATOMIns=ATOM.y;	%             Orthogonal coordinates for Y in Angstroms.
	case 10
	    ATOMIns=ATOM.z;	%             Orthogonal coordinates for Z in Angstroms.
	case 11
	    ATOMIns=ATOM.occupancy;	%     Occupancy.
	case 12
	    ATOMIns=ATOM.beta;	%    Temperature factor.
	case 13
	    ATOMIns=ATOM.segname;	%         Segment identifier, left-justified.
	case 14
	    ATOMIns=ATOM.element;	%       Element symbol, right-justified.
	case 15
	    ATOMIns=ATOM.charge;	%        Charge on the atom.
	end
	
	
	%==================  Renumbering column
	LastOldNumber=ATOMIns(1);	%The old residue number of first atom
	LastNewNumber=1;	%The new residue number of first atom
	ATOMIns(1)=1;
	
	for i=2:length(ATOMIns)
	    if ATOMIns(i)~= LastOldNumber;	%new residue begins
		LastNewNumber=LastNewNumber+1;
	    end
	    LastOldNumber=ATOMIns(i);
	    ATOMIns(i)=LastNewNumber;	%assigning the same new number
	end

	
	%==================  Insert final data into PDB
	switch DestColn	%Select column in ATOM to insert data
	case 1
	    ATOM.index=ATOMIns;	%        Atom serial number.
	case 2
	    ATOM.name=ATOMIns;	%          Atom name.
	case 3
	    ATOM.altloc=ATOMIns;	%        Alternate location indicator.
	case 4
	    ATOM.resname=ATOMIns;	%       Residue name.
	case 5
	    ATOM.chain=ATOMIns;	%       Chain identifier.
	case 6
	    ATOM.resid=ATOMIns;	%        Residue sequence number.
	case 7
	    ATOM.icode=ATOMIns;	%         Code for insertion of residues.
	case 8
	    ATOM.x=ATOMIns;	%             Orthogonal coordinates for X in Angstroms.
	case 9
	    ATOM.y=ATOMIns;	%             Orthogonal coordinates for Y in Angstroms.
	case 10
	    ATOM.z=ATOMIns;	%             Orthogonal coordinates for Z in Angstroms.
	case 11
	    ATOM.occupancy=ATOMIns;	%     Occupancy.
	case 12
	    ATOM.beta=ATOMIns;	%    Temperature factor.
	case 13
	    if iscell(ATOMIns)	%Cell type data to insert
		ATOM.segname=ATOMIns;	%         Segment identifier, left-justified.
	    elseif ischar(ATOMIns)	%char data
		ATOM.segname=cellstr(ATOMIns);	%         Segment identifier, left-justified.
	    else	%numeric data
		if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
		ATOM.segname=cellstr(num2str(ATOMIns))';	%         Segment identifier, left-justified.
	    end
	case 14
	    if iscell(ATOMIns)	%Cell type data to insert
		ATOM.element=ATOMIns;	%       Element symbol, right-justified
	    elseif ischar(ATOMIns)	%char data
		ATOM.element=cellstr(ATOMIns);	%       Element symbol, right-justified
	    else	%numeric data
		if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
		ATOM.element=cellstr(num2str(ATOMIns))';	%       Element symbol, right-justified
	    end
	case 15
	    if iscell(ATOMIns)	%Cell type data to insert
		ATOM.charge=ATOMIns;	%        Charge on the atom
	    elseif ischar(ATOMIns)	%char data
		ATOM.charge=cellstr(ATOMIns);	%        Charge on the atom
	    else	%numeric data
		if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
		ATOM.charge=cellstr(num2str(ATOMIns))';	%        Charge on the atom
	    end
	end
	
	writePDBfull([s{m},'_new.pdb'],ATOM,Fields,1);
	SndNp(2);
    end
    
    
    %beep;
    disp('Finished');
end





%_________________________________________

function insertATOMdata(DestColn,ATOMposition,DataIns)
global ATOM

for i=ATOMposition	%position in ATOM list
    switch DestColn	%Select column in ATOM to insert data
    case 1
	ATOM.index(i)=DataIns;	%        Atom serial number.
    case 2
	ATOM.name{i}=DataIns;	%          Atom name.
	
    case 3
	ATOM.altloc{i}=DataIns;	%        Alternate location indicator.
	
    case 4
	ATOM.resname{i}=DataIns;	%       Residue name.
	
    case 5
	ATOM.chain{i}=DataIns;	%       Chain identifier.
	
    case 6
	ATOM.resid(i)=DataIns;	%        Residue sequence number.
	
    case 7
	ATOM.icode{i}=DataIns;	%         Code for insertion of residues.
	
    case 8
	ATOM.x(i)=DataIns;	%             Orthogonal coordinates for X in Angstroms.
	
    case 9
	ATOM.y(i)=DataIns;	%             Orthogonal coordinates for Y in Angstroms.
	
    case 10
	ATOM.z(i)=DataIns;	%             Orthogonal coordinates for Z in Angstroms.
	
    case 11
	ATOM.occupancy(i)=DataIns;	%     Occupancy.
	
    case 12
	ATOM.beta(i)=DataIns;	%    Temperature factor.
	
    case 13
	ATOM.segname{i}=DataIns;	%         Segment identifier, left-justified.
	
    case 14
	ATOM.element{i}=DataIns;	%       Element symbol, right-justified.
	
    case 15
	ATOM.charge{i}=DataIns;	%        Charge on the atom.
    end
    
end


function ATOMIns=insertATOMIns(ATOMIns,ATOMposition,DataIns)
%Inserts single data value from DataIns into (multiple) ATOMIns position(s)

for i=ATOMposition	%position in ATOM list
    ATOMIns(i)=DataIns;
end