function prop3davrg(s,DistrType,DataColumn,DataInclude,CritColumn,SelectCrit,CoefColumn,CoefInclude,...
	BinWidth,AverNeighb,AverMode);
%prop3davrg Function averaging atoms' property in 3D space among the atoms
%occupancy column should contain coefficients (e.g. exposed area) to multiply on the value at the proportional avraging
%beta column should contain hydration energy data (in kcal/mol)
%INPUTS:
%s	- cell array with filenames
%DistrType	- Select type of distribution - 'Add value to every atom in the bin' <1>,'Divide value equally between the atoms in the bin' <2>,'Divide value proportionnaly between the atoms in the bin' <3>
%DataColumn	- Column with data for calculation
%DataInclude	- Select data to include into the calculation - all the data <1>*, positive <2>, negative <3>
%CritColumn	- Column with criterion for including into the calculation
%SelectCrit	- Select surface for calculation - outside <1>*, inside <2>, all <3>
%CoefColumn	- Column with coefficients to multiply parameter value. By default - exposed atom area
%CoefInclude	- Select coefficients, which should be included to the calcualtion 
%AverNeighb	- Averaging among ... neighbors
%AverMode	- Averaging mode
%BinWidth	- width of bins (zones, distance between concentric spheres) by which space near the atom is distributed

%Output
%
dbstop if error

if ~isempty(s)
	ATOM=[];
	%============ATOM array initialization
	ATOM.line=[];	%Number of the line in PDB file
	ATOM.index=[];	%        Atom serial number.
	ATOM.name={};	%          Atom name.
	ATOM.altloc={};	%        Alternate location indicator.
	ATOM.resname={};	%       Residue name.
	ATOM.chain={};	%       Chain identifier.
	ATOM.resid=[];	%        Residue sequence number.
	ATOM.icode={};	%         Code for insertion of residues.
	ATOM.x=[];	%             Orthogonal coordinates for X in Angstroms.
	ATOM.y=[];	%             Orthogonal coordinates for Y in Angstroms.
	ATOM.z=[];	%             Orthogonal coordinates for Z in Angstroms.
	ATOM.occupancy=[];	%     Occupancy.
	ATOM.beta=[];	%    Temperature factor.
	ATOM.segname={};	%         Segment identifier, left-justified.
	ATOM.element={};	%       Element symbol, right-justified.
	ATOM.charge={};	%        Charge on the atom.
	ATOM.pdb=[];	%content of the PDB file
	
	%     Fields(1)=0;%        Atom serial number.
	%     Fields(2)=0; %          Atom name.
	%     Fields(3)=0; %        Alternate location indicator.
	%     Fields(4)=0; %       Residue name.
	%     Fields(5)=0; %       Chain identifier.
	%     Fields(6)=0; %        Residue sequence number.
	%     Fields(7)=0; %         Code for insertion of residues.
	%     Fields(8)=0; %             Orthogonal coordinates for X in Angstroms.
	%     Fields(9)=0; %             Orthogonal coordinates for Y in Angstroms.
	%     Fields(10)=1; %             Orthogonal coordinates for Z in Angstroms.
	%     Fields(11)=1; %     Occupancy.
	%     Fields(12)=1; %    Temperature factor.
	%     Fields(13)=0; %         Segment identifier, left-justified.
	%     Fields(14)=0; %       Element symbol, right-justified.
	%     Fields(15)=0; %        Charge on the atom.
	
	Fields(1:15)=1;
	ProfNames=s;
	
	for m=1:length(s)
		tic
		ATOM(m)=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
		ProgressBarFile(m);
		disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM(m).line)), '-atoms structure read']);
		toc
		SndNp(2);
	end
	
	
	
	
	%=========== averaging property
	Outside=0;
	switch AverMode
	case {1 2}	%mean, smoothing averaging
		Outside=AverNeighb;	
	case 3	%Averaging with custom coefficients
		Outside=length(AverNeighb)-1;
	end
	
	BinsZ=0:BinWidth:BinWidth*(Outside+1);	%bins boundaries
	%MBinsZ=(BinsZ(1:(end-1))+BinsZ(2:end))/2;	%bins medians
	DistrProp=zeros(length(s),max(length(ATOM(1).index)));	%Initializing redistributed property matrix
	%FirstExposureCalculation=1;	%Flag for first exposure calculation 
	
	for m=1:length(s)	%Cycle through the files
		switch DataColumn	%Select column in ATOM to read property data
		case 1
			PropData=ATOM(m).index;	%        Atom serial number.
		case 2
			PropData=ATOM(m).name;	%          Atom name.
		case 3
			PropData=ATOM(m).altloc;	%        Alternate location indicator.
		case 4
			PropData=ATOM(m).resname;	%       Residue name.
		case 5
			PropData=ATOM(m).chain;	%       Chain identifier.
		case 6
			PropData=ATOM(m).resid;	%        Residue sequence number.
		case 7
			PropData=ATOM(m).icode;	%         Code for insertion of residues.
		case 8
			PropData=ATOM(m).x;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			PropData=ATOM(m).y;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			PropData=ATOM(m).z;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			PropData=ATOM(m).occupancy;	%     Occupancy.
		case 12
			PropData=ATOM(m).beta;	%    Temperature factor.
		case 13
			PropData=ATOM(m).segname;	%         Segment identifier, left-justified.
		case 14
			PropData=ATOM(m).element;	%       Element symbol, right-justified.
		case 15
			PropData=ATOM(m).charge;	%        Charge on the atom.
		end
		
		if iscell(PropData)	%If PropData is cellular array it should be converted to numerical
			PropDataT=[];
			for i=1:length(PropData)
				PropDataT(i)=eval(['0' PropData{i}]);
			end
			PropData=PropDataT;
		end
		
		switch CritColumn	%Select column in ATOM to read property criterion data
		case 1
			PropCrit=ATOM(m).index;	%        Atom serial number.
		case 2
			PropCrit=ATOM(m).name;	%          Atom name.
		case 3
			PropCrit=ATOM(m).altloc;	%        Alternate location indicator.
		case 4
			PropCrit=ATOM(m).resname;	%       Residue name.
		case 5
			PropCrit=ATOM(m).chain;	%       Chain identifier.
		case 6
			PropCrit=ATOM(m).resid;	%        Residue sequence number.
		case 7
			PropCrit=ATOM(m).icode;	%         Code for insertion of residues.
		case 8
			PropCrit=ATOM(m).x;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			PropCrit=ATOM(m).y;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			PropCrit=ATOM(m).z;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			PropCrit=ATOM(m).occupancy;	%     Occupancy.
		case 12
			PropCrit=ATOM(m).beta;	%    Temperature factor.
		case 13
			PropCrit=ATOM(m).segname;	%         Segment identifier, left-justified.
		case 14
			PropCrit=ATOM(m).element;	%       Element symbol, right-justified.
		case 15
			PropCrit=ATOM(m).charge;	%        Charge on the atom.
		end
		
		if iscell(PropCrit)	%If PropCrit is cellular array it should be converted to numerical
			PropCritT=[];
			for i=1:length(PropCrit)
				PropCritT(i)=eval(['0' PropCrit{i}]);
			end
			PropCrit=PropCritT;
		end
		
		switch CoefColumn	%Select column in ATOM to read property criterion data
		case 1
			PropCoef=ATOM(m).index;	%        Atom serial number.
		case 2
			PropCoef=ATOM(m).name;	%          Atom name.
		case 3
			PropCoef=ATOM(m).altloc;	%        Alternate location indicator.
		case 4
			PropCoef=ATOM(m).resname;	%       Residue name.
		case 5
			PropCoef=ATOM(m).chain;	%       Chain identifier.
		case 6
			PropCoef=ATOM(m).resid;	%        Residue sequence number.
		case 7
			PropCoef=ATOM(m).icode;	%         Code for insertion of residues.
		case 8
			PropCoef=ATOM(m).x;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			PropCoef=ATOM(m).y;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			PropCoef=ATOM(m).z;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			PropCoef=ATOM(m).occupancy;	%     Occupancy.
		case 12
			PropCoef=ATOM(m).beta;	%    Temperature factor.
		case 13
			PropCoef=ATOM(m).segname;	%         Segment identifier, left-justified.
		case 14
			PropCoef=ATOM(m).element;	%       Element symbol, right-justified.
		case 15
			PropCoef=ATOM(m).charge;	%        Charge on the atom.
		end
		
		if iscell(PropCoef)	%If PropCoef is cellular array it should be converted to numerical
			PropCoefT=[];
			for i=1:length(PropCoef)
				PropCoefT(i)=eval(['0' PropCoef{i}]);
			end
			PropCoef=PropCoefT;
		end
		
		
		DistrProp(m,1)=0;	%Initialize new row for distributed property array
		
		%Calculate distribution coefficients
		DistrCoefts=zeros(1,(length(BinsZ)-1));
		switch AverMode
		case 1	%mean
			DistrCoefts=1/length(DistrCoefts);	%Smoothing vector
		case 2	%smoothing averaging
			StepAm=length(DistrCoefts);
			DistrCoefts(1:StepAm)=(StepAm:-1:1)/sum(1:StepAm);	%Smoothing vector
		case 3	%Averaging with custom coefficients
			DistrCoefts=AverNeighb;	%Smoothing vector
		end
		
		for i=1:length(ATOM(m).resid)	%Cycle through the Atoms
			
			%----- Condition check and value addition
			GoCrit=0;
			switch SelectCrit	%Criterion for including the point into consideration
			case 1	%Outer
				if PropCrit(i)==1; GoCrit=1;	end
			case 2	%inner
				if PropCrit(i)==-1; GoCrit=1;	end
			case 3	%all
				GoCrit=1;
			end
			
			GoData=0; 
			switch DataInclude	%Criterion by data value for including the point into consideration
			case 1	%all
				GoData=1;
			case 2	%Outer
				if PropData(i)>0; GoData=1;	end
			case 3	%inner
				if PropData(i)<0; GoData=1;	end
			end
			
			
			if GoCrit==1&GoData==1  %the point satisfies the criterion and data satisfies data condition
				%Compile atoms list by zones
				%Look through all the atoms - can be accelerated by preliminary run
				distance=[];
				distance=((ATOM(m).x(i)-ATOM(m).x).^2+(ATOM(m).y(i)-ATOM(m).y).^2+(ATOM(m).z(i)-ATOM(m).z).^2).^0.5;	%distance between two atoms	
				BinsZAtoms={};
				for j=1:(length(BinsZ)-1)	%Cycle through the bins
					BinsZAtoms{j}=find(distance>=BinsZ(j)&distance<BinsZ(j+1));	%all the atoms that fit the spherical bin
				end
				
				%Distribute property of current atom between selected atoms in bins
				switch DistrType	%Select type of distribution - 'Add value to every atom in the bin' <1>,'Divide value equally between the atoms in the bin' <2>,'Divide value proportionnaly between the atoms in the bin' <3>
				case 1	%Add value to every atom in the bin
					for k=1:length(BinsZAtoms);	%Cycle through the bins
						DistrProp(m,BinsZAtoms{k})=DistrProp(m,BinsZAtoms{k})+PropData(i)*DistrCoefts(k);
					end
				case 2	%Divide value equally between the atoms in the bin
					%Correct distribution coefficients to take into account bins with no atoms in order to preserve total energy
					divider=0;
					for k=1:length(BinsZAtoms)
						if length(BinsZAtoms{k})>0
							divider=divider+DistrCoefts(k);
						end
					end
					DistrCoefts=DistrCoefts/divider;
					
					for k=1:length(BinsZAtoms);	%Cycle through the bins
						if length(BinsZAtoms{k})>0
							DistrProp(m,BinsZAtoms{k})=DistrProp(m,BinsZAtoms{k})+PropData(i)*DistrCoefts(k)/length(BinsZAtoms{k});
						end
					end
				case 3	%Divide value proportionnaly between the atoms in the bin
					%exclude atoms which didn't fit by coefficient criterion
					for k=1:length(BinsZAtoms)
						if length(BinsZAtoms{k})>0
							switch CoefInclude	%Criterion by coefficient for including the point into consideration
							case 1	%Positive
								BinsZAtoms{k}=BinsZAtoms{k}(PropCoef(BinsZAtoms{k}>0));
							case 2	%>50% of exposed area
								%Has to be fixed                if PropData(i)<0; GoCoef=1;	end
							case 3	%all
							end
						end
					end
					
					
					%Correct distribution coefficients to take into account bins with no atoms in order to preserve total energy
					divider=0;
					for k=1:length(BinsZAtoms)
						if length(BinsZAtoms{k})>0
							if sum(BinsZAtoms{k})~=0
								divider=divider+DistrCoefts(k);
							else
								BinsZAtoms{k}=[];
							end
						end
					end
					DistrCoefts=DistrCoefts/divider;
					
					for k=1:length(BinsZAtoms);	%Cycle through the bins
						if length(BinsZAtoms{k})>0
							%Divide between atoms in the current zone proportionally to the coefficient of each atom
							DistrProp(m,BinsZAtoms{k})=DistrProp(m,BinsZAtoms{k})+PropData(i)*DistrCoefts(k).*BinsZAtoms{k}/(sum(BinsZAtoms{k})*length(BinsZAtoms{k}));
						end
					end	%Cycle through the bins
				end	%Select type of distribution - 'Add value to every atom in the bin' <1>,'Divide value equally between the atoms in the bin' <2>,'Divide value proportionnaly between the atoms in the bin' <3>
			end  %the point satisfies the criterion and data satisfies data condition
		end	%Cycle through the Atoms
		
		%==================  Insert final data into PDB
		ATOMIns=DistrProp(m,:);	%take current column to insert
		switch DataColumn	%Select column in ATOM to insert data - the same as initial data column
		case 1
			ATOM(m).index=ATOMIns;	%        Atom serial number.
		case 2
			ATOM(m).name=ATOMIns;	%          Atom name.
		case 3
			ATOM(m).altloc=ATOMIns;	%        Alternate location indicator.
		case 4
			ATOM(m).resname=ATOMIns;	%       Residue name.
		case 5
			ATOM(m).chain=ATOMIns;	%       Chain identifier.
		case 6
			ATOM(m).resid=ATOMIns;	%        Residue sequence number.
		case 7
			ATOM(m).icode=ATOMIns;	%         Code for insertion of residues.
		case 8
			ATOM(m).x=ATOMIns;	%             Orthogonal coordinates for X in Angstroms.
		case 9
			ATOM(m).y=ATOMIns;	%             Orthogonal coordinates for Y in Angstroms.
		case 10
			ATOM(m).z=ATOMIns;	%             Orthogonal coordinates for Z in Angstroms.
		case 11
			ATOM(m).occupancy=ATOMIns;	%     Occupancy.
		case 12
			ATOM(m).beta=ATOMIns;	%    Temperature factor.
		case 13
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM(m).segname=ATOMIns;	%         Segment identifier, left-justified.
			elseif ischar(ATOMIns)	%char data
				ATOM(m).segname=cellstr(ATOMIns);	%         Segment identifier, left-justified.
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM(m).segname=cellstr(num2str(ATOMIns))';	%         Segment identifier, left-justified.
			end
		case 14
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM(m).element=ATOMIns;	%       Element symbol, right-justified
			elseif ischar(ATOMIns)	%char data
				ATOM(m).element=cellstr(ATOMIns);	%       Element symbol, right-justified
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM(m).element=cellstr(num2str(ATOMIns))';	%       Element symbol, right-justified
			end
		case 15
			if iscell(ATOMIns)	%Cell type data to insert
				ATOM(m).charge=ATOMIns;	%        Charge on the atom
			elseif ischar(ATOMIns)	%char data
				ATOM(m).charge=cellstr(ATOMIns);	%        Charge on the atom
			else	%numeric data
				if size(ATOMIns,1)<size(ATOMIns,2); ATOMIns=ATOMIns'; end	%Making array vertical
				ATOM(m).charge=cellstr(num2str(ATOMIns))';	%        Charge on the atom
			end
		end
		
		writePDBfull([s{m},'_3Daver.pdb'],ATOM(m),Fields,1);
		SndNp(2);
		%writePDBfull(s{end},ATOM(end),Fields,1)
		
		disp('Finished');
	end
end
