function ATOM = readPDBfull(fname1,Fields,OrigPDB)
%dbstop if error
%this function d=reads PDB file into structure array
%input:
%fname1 - filename for PDB file
%Fields	- Vector indicating fields of PDB to read (default - all)
%KeepPDB - Keep full PDB content
%Output:
%ATOM - structure array with the fields corresponding to ones in ATOM record of PDB file


TempZipFileName=unzip_AGA(fname1);  %Temporary Unzip file, if necesary


if nargin == 1
	Fields=ones(1,15);
	OrigPDB=1;
end

%fid = fopen (fname1,'r');
%numlines = 0; 
%ENDT = ' ';
%====ATOM strings reading
%while ENDT ~= 'END'
%	numlines = numlines + 1;
%	t = fgets (fid);
%	A (numlines,1:80)=' ';
%	A (numlines, 1:length(t)) = t;
%	ENDT = A (numlines, 1:3);
%end 
%fclose (fid);

A=textread(fname1,'%s','delimiter','\n','whitespace','');
numlines=length(A);
t(1:80)=' '; t(1:length(A{1}))=A{1};
A{1}=t;
A=char(A);

%============ATOM array initialization
ATOM.line=[];	%Number of the line in PDB file
ATOM.index=[];	%        Atom serial number.
ATOM.name={};	%          Atom name.
ATOM.altloc={};	%        Alternate location indicator.
ATOM.resname={};	%       Residue name.
ATOM.chain={};	%       Chain identifier.
ATOM.resid=[];	%        Residue sequence number.
ATOM.icode={};	%         Code for insertion of residues.
ATOM.x=[];	%             Orthogonal coordinates for X in Angstroms.
ATOM.y=[];	%             Orthogonal coordinates for Y in Angstroms.
ATOM.z=[];	%             Orthogonal coordinates for Z in Angstroms.
ATOM.occupancy=[];	%     Occupancy.
ATOM.beta=[];	%    Temperature factor.
ATOM.segname={};	%         Segment identifier, left-justified.
ATOM.element={};	%       Element symbol, right-justified.
ATOM.charge={};	%        Charge on the atom.

if OrigPDB==1	%Remember the content of original PDB file
	ATOM.pdb=A;	%full content of the PDB file
else
	ATOM.pdb=[];	%no content of the PDB file
end

%  1 -  6        Record name     &quot;ATOM  &quot;
%  7 - 11        Integer         serial        Atom serial number.
% 13 - 16        Atom            name          Atom name.
% 17             Character       altLoc        Alternate location indicator.
% 18 - 20        Residue name    resName       Residue name.
% 22             Character       chainID       Chain identifier.
% 23 - 26        Integer         resSeq        Residue sequence number.
% 27             AChar           iCode         Code for insertion of residues.
% 31 - 38        Real(8.3)       x             Orthogonal coordinates for X in
%                                              Angstroms.
% 39 - 46        Real(8.3)       y             Orthogonal coordinates for Y in
%                                              Angstroms.
% 47 - 54        Real(8.3)       z             Orthogonal coordinates for Z in
%                                              Angstroms.
% 55 - 60        Real(6.2)       occupancy     Occupancy.
% 61 - 66        Real(6.2)       tempFactor    Temperature factor.
% 73 - 76        LString(4)      segID         Segment identifier, left-justified.
% 77 - 78        LString(2)      element       Element symbol, right-justified.
% 79 - 80        LString(2)      charge        Charge on the atom.

tic; ProgressReportTime=toc;

%=========== ATOM array filling out
for i = 1 : numlines
	if (A(i,1:4)=='ATOM' | A(i,1:4)=='HETA')
		ATOM.line(end+1)=i;
		if Fields(1)==1; ATOM.index(end+1)=sscanf(A(i,7:11),'%i'); end	%        Atom serial number.
		if Fields(2)==1; ATOM.name{end+1}=sscanf(A(i,13:16),'%s'); end	%          Atom name.
		if Fields(3)==1; ATOM.altloc{end+1}=sscanf(A(i,17),'%c'); end	%        Alternate location indicator.
		if Fields(4)==1; ATOM.resname{end+1}=sscanf(A(i,18:20),'%s'); end	%       Residue name.
		if Fields(5)==1; ATOM.chain{end+1}=sscanf(A(i,22),'%c'); end	%       Chain identifier.
		if Fields(6)==1; ATOM.resid(end+1)=sscanf(A(i,23:26),'%i'); end	%        Residue sequence number.
		if Fields(7)==1; ATOM.icode{end+1}=sscanf(A(i,27),'%c'); end	%         Code for insertion of residues.
		if Fields(8)==1; ATOM.x(end+1)=sscanf(A(i,31:38),'%f'); end	%             Orthogonal coordinates for X in Angstroms.
		if Fields(9)==1; ATOM.y(end+1)=sscanf(A(i,39:46),'%f'); end	%             Orthogonal coordinates for Y in Angstroms.
		if Fields(10)==1; ATOM.z(end+1)=sscanf(A(i,47:54),'%f'); end	%             Orthogonal coordinates for Z in Angstroms.
		if Fields(11)==1; ATOM.occupancy(end+1)=sscanf(A(i,55:60),'%f'); end	%     Occupancy.
		if Fields(12)==1; ATOM.beta(end+1)=sscanf(A(i,61:66),'%f'); end	%    Temperature factor.
		if Fields(13)==1; ATOM.segname{end+1}=sscanf(A(i,73:76),'%s'); end	%         Segment identifier, left-justified.
		if Fields(14)==1; ATOM.element{end+1}=sscanf(A(i,77:78),'%s'); end	%       Element symbol, right-justified.
		if Fields(15)==1; ATOM.charge{end+1}=sscanf(A(i,79:80),'%s'); end	%        Charge on the atom.
	end
	%Progress report block - optional
	CurrentProgressTime=toc;
	if (CurrentProgressTime-ProgressReportTime)>0.5	%Time to report progress
		try ProgressBarLocal(i,numlines);%Set current value on the local progress bar
		end
		ProgressReportTime=CurrentProgressTime;
	end	%Time to report progress
	
end

%disp([num2str(size(ATOM.index)), ' atoms structure read']);
%plot(ATOM.x)%!

unzip_AGA(fname1,TempZipFileName);  %Remove Temporary Unzip file, if necesary

