function POINT = readVRMLfull(fname1,Fields,OrigVRML)
%dbstop if error
%this function reads VRML file into structure array
%input:
%fname1 - filename for VRML file
%Fields	- Vector indicating fields of VRML to read
%OrigVRML - Keep full VRML content
%Output:
%POINT - structure array with the fields corresponding to ones in POINT record of VRML file
global A i ProgressReportTime numlines

TempZipFileName=unzip_AGA(fname1);  %Temporary Unzip file, if necesary

tic
if nargin == 1
	Fields=ones(1,4);
	OrigVRML=0;
end

A='';

A=textread(fname1,'%s','delimiter','\n','whitespace','');
A=char(A);
% fid=fopen(fname1);
% tline = fgetl(fid);
% while ischar(tline)
% 	if length(tline)>0
% 		A(end+1,1:length(tline))=tline;
% 	end
% 	tline = fgetl(fid);
% end
% fclose(fid);
numlines=length(A);%!!!
%toc

%============POINT array initialization
POINT.Coordinate3=zeros(3,0);	% Indexed (PER_VERTEX) Orthogonal XYZ coordinates for the vertices - 3xN matrix: [X; Y; Z]. N - number of vertices
POINT.IndexedFaceSet=zeros(4,0);	%  Indexed (per facet) IndexedFaceSet 4xM [Poin1; Point2; Point3; Parameter]. M - number of facets
POINT.Normal=zeros(3,0);	%    Indexed (PER_VERTEX) Normal vectors matrix: - 3xM matrix: [X; Y; Z]. M - number of facets
POINT.Material=zeros(3,0);	% Indexed (PER_VERTEX) material color for the vertices - 3xN matrix: [R; G; B]. N - number of vertices (the rest of material properties are not used for a while)

if OrigVRML==1	%Remember the content of original VRML file
	POINT.VRML=A;	%full content of the VRML file
else
	POINT.VRML=[];	%no content of the VRML file
end


%=========== POINT array filling out
% Material { 
% diffuseColor 0.650000 0.650000 0.650000
% ambientColor 0.000000 0.000000 0.000000
% specularColor 1.000000 1.000000 1.000000
% shininess 40.000000
% transparency 0.000000
% }
% Normal { vector [
%  -0.427600 0.855300 -0.292400,
%  -0.246600 0.945400 -0.213100,
%  -0.186100 0.913600 -0.361600
%  ] }
% Coordinate3 {point [
%  3.387400 8.011300 2.815600,
%  3.568400 8.101400 2.894900,
%  3.628900 8.069600 2.746400
%  ] }
% IndexedFaceSet { coordIndex [0, 1, 2, -1] }

% NormalBinding {value PER_VERTEX_INDEXED} 
% Separator {
% MaterialBinding {value PER_VERTEX_INDEXED} 
% Material { 
% diffuseColor [ 
% 0.94 0.94 1.00, 
% 0.94 0.94 1.00, 
% 0.94 0.94 1.00
% ] }

%-------- Remove all the comments
for i=1:numlines
	Comment=findstr(A(i,:),'#');
	if ~isempty(Comment)
		A(i,Comment(1):end)=' ';
	end
end

%-------------   Read the data
i=1;
CoordinateSetsRead=0;	%Number of objects for which facet sets were read
FacetSetsRead=0;	%Number of objects for which facet sets were read
NormalSetsRead=0;	%Number of objects for which normal sets were read
LastVerticesNumber=0;	%Number of vertices read in the last set of vertices

ProgressReportTime=toc;
while i <= numlines
	if ~isempty(findstr(A(i,:),'Coordinate3'))	%There is Coordinate3 keyword in the line
		NewDataBlock=ReadDataBlock('Coordinate3','{','}',3);	%(InitiationString, OpeningBracket, ClosingBracket, SupposedLength)
		POINT.Coordinate3=[POINT.Coordinate3,NewDataBlock];
		CoordinateSetsRead=CoordinateSetsRead+1;
		LastVerticesNumber=size(NewDataBlock,2);
	elseif length(findstr(A(i,:),'IndexedFaceSet'))>0	%There is IndexedFaceSet keyword in the line
		NewDataBlock=ReadDataBlock('IndexedFaceSet','{','}',4);	%(InitiationString, OpeningBracket, ClosingBracket, SupposedLength)
		if FacetSetsRead>0	%there were  fecet sets read already
			if CoordinateSetsRead>FacetSetsRead	%New set of coordinates was read already
				NewDataBlock(1:3,:)=NewDataBlock(1:3,:)+size(POINT.Coordinate3,2)-LastVerticesNumber;
			else	%New set of facetes was read first
				NewDataBlock(1:3,:)=NewDataBlock(1:3,:)+size(POINT.Coordinate3,2);
			end
		end
		POINT.IndexedFaceSet=[POINT.IndexedFaceSet,NewDataBlock];
		FacetSetsRead=FacetSetsRead+1;
	elseif length(findstr(A(i,:),'Normal '))>0	%There is Normal keyword in the line
		NewDataBlock=ReadDataBlock('Normal ','{','}',3);	%(InitiationString, OpeningBracket, ClosingBracket, SupposedLength)
		POINT.Normal=[POINT.Normal,NewDataBlock];
		NormalSetsRead=NormalSetsRead+1;
	elseif length(findstr(A(i,:),'Material'))>0	%There is Material keyword in the line
		%not implemented yet
		% 		NewDataBlock=ReadDataBlock('Material','{','}',3);	%(InitiationString, OpeningBracket, ClosingBracket, SupposedLength)
		% 		POINT.Material=[POINT.Material,NewDataBlock];
	end
	i=i+1;
	

end
POINT.IndexedFaceSet(1:3,:)=POINT.IndexedFaceSet(1:3,:)+1;	%shift from "zero" index of the first point to "1"

disp([num2str(numlines), ' lines in the VRML file. ',...
		num2str(length(POINT.Coordinate3)), ' vertices of ',...
		num2str(length(POINT.Material)), ' colors, ',...
		num2str(length(POINT.Normal)), ' normals, and ',...
		num2str(length(POINT.IndexedFaceSet)), ' facets. Time spent, s: ',...
	num2str(toc)]);



function CrntString=CleanNonNumericalSymbols(CrntString)
%fnction cleaning all the symbols except numbers, "-" sign, spaces and dots.
list=[43,45,46,48:57];	%list of character codes allowed to be left
replace=[];
DoubleCrntString=double(CrntString);
for i=1:length(CrntString)
	if any(list==DoubleCrntString(i))
		replace(i)=0;
	else
		replace(i)=1;
	end
end
CrntString(find(replace))=' ';




function NewDataBlock=ReadDataBlock(InitiationString, OpeningBracket, ClosingBracket, SupposedLength)
%function to read the block of data after the specified keyword
%Inputs:
%InitiationString	- String starting from which data should be read
%OpeningBracket	- The first such opening bracket after InitiationString shows beginning of data block
%ClosingBracket	- The first such opening bracket after InitiationString shows end of data block
%SupposedLength	- Supposed number of data points in one line
%Outputs:
%NewDataBlock	- Block of data with indexes in the first and data in other

global A i ProgressReportTime numlines

NewDataBlock=zeros(SupposedLength,0);	%Initialization
%Now look for the opening bracket "{" position
CrntString=A(i,(findstr(A(i,:),InitiationString)+length(InitiationString)):end);
BrPos=findstr(CrntString,OpeningBracket);
while isempty(BrPos)
	i=i+1; CrntString=A(i,:);
	BrPos=findstr(CrntString,OpeningBracket);
end
CrntString=CrntString((BrPos+1):end);
%Now look for the closing bracket "}" position
BrPos=findstr(CrntString,ClosingBracket);
while isempty(BrPos)
	%Read current string
	CrntNumbers=sscanf(CrntString,'%f');	%Try to read the string
	if length(CrntNumbers)~=SupposedLength	%Try to clean the string
		CrntString=CleanNonNumericalSymbols(CrntString);
		CrntNumbers=sscanf(CrntString,'%f');	%Try to read the string
	end
	if length(CrntNumbers)==SupposedLength	%Add new item to the array if some numbers were read
		NewDataBlock(1:SupposedLength,end+1)=CrntNumbers;
	end
	%Look for the bracket in the next line
	i=i+1; CrntString=A(i,:); BrPos=findstr(CrntString,ClosingBracket);
	
	%Progress report block - optional
	CurrentProgressTime=toc;
	if (CurrentProgressTime-ProgressReportTime)>0.5	%Time to report progress
		try ProgressBarLocal(i,numlines);%Set current value on the local progress bar
		end
		ProgressReportTime=CurrentProgressTime;
	end	%Time to report progress
end

if BrPos > 1	%If bracket is not at the beginning of the line, try to read numbers before it
	CrntString=A(i,(BrPos+1):end);
	CrntNumbers=sscanf(CrntString,'%f');	%Try to read the string
	if length(CrntNumbers)~=SupposedLength	%Try to clean the string
		CrntString=CleanNonNumericalSymbols(CrntString);
		CrntNumbers=sscanf(CrntString,'%f');
	end
	if length(CrntNumbers)==SupposedLength	%Add new item to the array if some numbers were read
		NewDataBlock(1:SupposedLength,end+1)=CrntNumbers;
	end
end

unzip_AGA(fname1,TempZipFileName);  %Remove Temporary Unzip file, if necesary
