function volmcros(s,FileType,FileInfo,PlotSurf,PlotCrosContr,PlotCrosAreas,PlotCrosRadii,PlotCrosPerim,...
		PrintSurf,PrintCrosContr,PrintCrosAreas,PrintCrosRadii,PrintCrosPerim,...
		ImageSurf,ImageCrosContr,ImageCrosAreas,ImageCrosRadii,ImageCrosPerim,...
        SaveSurf,SaveCrosContr,SaveCrosAreas,SaveCrosRadii,SaveCrosPerim,CrosNormalType,CrosNormal,PlotContourLevel,...
		GridStepType,GridStep,SectNum,CalcMethod,SortMethod,VDWRadiusSource,VDWFileType,DataOligo,SrcColn,ZIPoutput);
dbstop if error
%Function to create a set of crossections through volumetric density data, or PDB file, or VRML structure and calculate crossections areas/radii

%	inputs:
% 	s	- initial files list
%  	FileType	- initial file type {'*.pdb', '*.txt', '*.*','*.mat','*.wrl'}
% 	FileInfo	- file with VDW radii data
% 	PlotSurf	- Flag to plot molecular surfaces
% 	PlotCrosContr	- Flag to plot calculated contours
% 	PlotCrosAreas	- Flag to plot crossections areas
% 	PlotCrosRadii	- Flag to plot crossections radii
%	PlotCrosPerim	- Flag to plot crossections perimeter length
% 	SaveSurf	- Option not to save <1> or save in file the calculated surfaces as VRML.mat <1> or text triangles <2>
% 	SaveCrosContr	- Flag to save in file the calculated crossections contours
% 	SaveCrosAreas	- Flag to save in file the calculated crossections areas
% 	SaveCrosRadii	- Flag to save in file the calculated crossections radii
%	SaveCrosPerim	- Flag to save in file the calculated crossections perimeter length
% 	CrosNormalType	- Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
% 	CrosNormal	- X,Y,Z values for the custom Normal to the crossection planes
% 	PlotContourLevel	- Level at which make a contour in volunetric data slice
% 	GridStepType	- Type of the calculation of slices grid steps - by the step length or number of steps{'Length, A','Steps'}
% 	GridStep	- Length of the grid step (in Angstroms) or number of steps in the grid
%	SectNum=get(findobj(oph,'Tag','o_SectNum'),'String');	%Number of sectors in crossection contour
%	CalcMethod	- Method of the calculation of slices crossection area
% 	VDWRadiusSource	- Source of data for assigning VDW radius for PDB atoms {'Guess VDW radii using atom names','VDW radii in the column of orig. PDB structure','VDW radii in the separate file','Zero VDW radii assigned for all the atoms'}
%	VDWFileType	- Format and type of the file with data of VDW radii {'*.pdb', '*.txt column', '*.psf', '*.*'}
% 	DataOligo	- Data per monomer, per whole oligomer, or per atom type  in source file
% 	SrcColn	- Default Source column for VDW radius data - beta
%	SortMethod=get(findobj(oph,'Tag','o_SortMethod'),'Value');	%Method of the sorting the contours within crossection

%SaveSurf = 2; %!!!

if ~isempty(s)
	ProgressBarGlobal(0,length(s));%Set current value on the global progress bar
	ProgressBarLocal(0,100);%Set current value on the global progress bar
	CrosProp.Area=[];	%Initialize an array with area data about calculated crossectons: columns - separate contours; rows - slices
	CrosProp.Radius=[];	%Initialize an array with radiu data about calculated crossectons: columns - separate contours; rows - slices
	CrosProp.Length=[];	%Initialize an array with perimeter length data about calculated crossectons: columns - separate contours; rows - slices
	CrosProp.CoordOrt=[];	%Initialize an array with orthogonal contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
	CrosProp.CoordPol=[];	%Initialize an array with polar contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
	Fields(1:15)=1;
	FirstStructure=1;	%This is the first structure read in this set
	for m=1:length(s)	%Cycle through the input files
		tic
		%=================Read initial file with 3D data
		switch FileType	%initial file type {'*.pdb', '*.txt', '*.*','*.mat','*.wrl'}
		case 1	%'*.pdb'
			ATOM=readPDBfull(s{m},Fields,1);	%=================Reads PDB structure file into structure array
			disp([num2str(m),'. ',s{m},':      ',num2str(length(ATOM.line)), '-atoms structure read']);
			POINT.Coordinate3=[ATOM.x;ATOM.y;ATOM.z];	%transfer coordinate data from ATOM array to POINT array for uniform calculations
		case 2	%'*.txt'
			disp('Wrong input file type. Exiting now...');
			return;
		case 3	%'*.*'
			disp('Wrong input file type. Exiting now...');
			return;
		case 4	%'*.mat'
            TempZipFileName=unzip_AGA(s{m});  %Temporary Unzip file, if necesary
			load('-MAT',s{m}); %load the file containing volumetric density data in fields VolmData vMBinsX vMBinsY vMBinsZ. These variables will be created in the workspace
            unzip_AGA(s{m},TempZipFileName);  %Remove Temporary Unzip file, if necesary
			%parameters to Convert surface coordinates from volumetric data to their real values
			vMinX=min(vMBinsX); vMaxX=max(vMBinsX);
			vMinY=min(vMBinsY); vMaxY=max(vMBinsY);
			vMinZ=min(vMBinsZ); vMaxZ=max(vMBinsZ);
			Ax=(vMaxX-vMinX)/(size(VolmData,1)-1); Bx=vMinX-Ax;
			Ay=(vMaxY-vMinY)/(size(VolmData,2)-1); By=vMinY-Ay;
			Az=(vMaxZ-vMinZ)/(size(VolmData,3)-1); Bz=vMinZ-Az;
			switch CalcMethod	%Method of the calculation of slices crossection area
			case {2 3 4 5}	%'By closest-farest points (PDB, VRML, *.mat)' 'By surface crossection point (VRML, *.mat)' 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				Surface=isosurface(permute(VolmData,[2 1 3]),PlotContourLevel);
				POINT.Coordinate3=Surface.vertices';
				POINT.IndexedFaceSet(1:3,:)=Surface.faces';
				clear Surface;
				%Convert surface coordinates from volumetric data to their real values
				POINT.Coordinate3(1,:)=Ax*POINT.Coordinate3(1,:)+Bx;
				POINT.Coordinate3(2,:)=Ay*POINT.Coordinate3(2,:)+By;
				POINT.Coordinate3(3,:)=Az*POINT.Coordinate3(3,:)+Bz;
				
			end	%Method of the calculation of slices crossection area
		case 5	%'*.wrl'
			POINT=readVRMLfull(s{m});	%Read VRML file into structural array with fields .Coordinate3 and .IndexedFaceSet
		case 6	%'*VRML.mat'
            TempZipFileName=unzip_AGA(s{m});  %Temporary Unzip file, if necesary
			load('-MAT',s{m}); %load the file containing VRML surface data in fields tmp1(from POINT.Coordinate3) and tmp2 (from POINT.IndexedFaceSet). These variables will be created in the workspace
            unzip_AGA(s{m},TempZipFileName);  %Remove Temporary Unzip file, if necesary
			POINT.Coordinate3=tmp1;	clear tmp1;
			POINT.IndexedFaceSet=tmp2; clear tmp2;
		end
		ProgressBarGlobal((m-1+0.4),length(s));%Set current value on the global progress bar
		ProgressBarFile(m);
		
		%Block for protein reorientation to make all the crossections normal to Z axis
		switch CrosNormalType	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
		case 1	%'X axis'
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%Volumetric crossection
				VolmData=permute(VolmData,[3 2 1]);	VolmData(:,:,:)=VolmData(end:-1:1,:,:);
				[vMBinsX,vMBinsZ]=swap(vMBinsX,-vMBinsZ);
			case {2 3 4 5}	%'By closest-farest points (PDB, VRML, *.mat)' 'By surface crossection point (VRML, *.mat)' 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				[POINT.Coordinate3(1,:),POINT.Coordinate3(3,:)]=swap(POINT.Coordinate3(1,:),-POINT.Coordinate3(3,:));
				if FileType==5	%VRML
					[POINT.Normal(1,:),POINT.Normal(3,:)]=swap(POINT.Normal(1,:),-POINT.Normal(3,:));
				end
			end	%Method of the calculation of slices crossection area
		case 2	%'Y axis'
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%Volumetric crossection
				VolmData=permute(VolmData,[1 3 2]);	VolmData(:,:,:)=VolmData(:,end:-1:1,:);
				[vMBinsY,vMBinsZ]=swap(vMBinsY,-vMBinsZ);
			case {2 3 4 5}	%'By closest-farest points (PDB, VRML, *.mat)' 'By surface crossection point (VRML, *.mat)' 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				[POINT.Coordinate3(2,:),POINT.Coordinate3(3,:)]=swap(POINT.Coordinate3(2,:),-POINT.Coordinate3(3,:));
				if FileType==5	%VRML
					[POINT.Normal(2,:),POINT.Normal(3,:)]=swap(POINT.Normal(2,:),-POINT.Normal(3,:));
				end
			end	%Method of the calculation of slices crossection area
		case 3	%'Z axis'
		case 4	%'Custom vector'
			%CrosNormal	- X,Y,Z values for the custom Normal to the crossection planes
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%Volumetric crossection
				disp('Not implemented yet');
				return
			case {2 3 4 5}	%'By closest-farest points (PDB, VRML, *.mat)' 'By surface crossection point (VRML, *.mat)' 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				%calculating2points on orientation vector goingthrough the geometry center of the molecule
				X_l=mean(POINT.Coordinate3(1,:)); %X coordinate of the geometry center
				Y_l=mean(POINT.Coordinate3(2,:)); %Y coordinate of the geometry center
				Z_l=mean(POINT.Coordinate3(3,:)); %Z coordinate of the geometry center
				X_h=X_l+CrosNormal(1);
				Y_h=Y_l+CrosNormal(2);
				Z_h=Z_l+CrosNormal(3);
				%disp(['Final orientation line coordinates [X_l,Y_l,Z_l,X_h,Y_h,Z_h]: ',...
				%		num2str([X_l,Y_l,Z_l,X_h,Y_h,Z_h])]);
				
				%____________ Find the rotation axis normal to the orientation line ([X_l,Y_l,Z_l],[X_h,Y_h,Z_h])
				%             and Z axis
				a_r=Y_l-Y_h;	%vector length in X direction
				b_r=X_h-X_l;	%vector length in Y direction
				c_r=0;	%vector length in Z direction
				AcosR=-acos((Z_h-Z_l)/((X_h-X_l)^2+(Y_h-Y_l)^2+(Z_h-Z_l)^2)^0.5);	%Rotation angle - angle of orientation line with Z axis
				disp(['Molecule was rotated by ', num2str(fix(abs(AcosR/3.1415*180))),' degrees']);
				
				%===================== Reorientation of the protein
				crd(1:length(POINT.Coordinate3(1,:)),1)=POINT.Coordinate3(1,:)';
				crd(:,2)=POINT.Coordinate3(2,:)';
				crd(:,3)=POINT.Coordinate3(3,:)';
				crd=rotate_coordinates(crd,[X_l,Y_l,Z_l],[a_r,b_r,c_r],AcosR);
				%read transformed coordinates
				POINT.Coordinate3(1,:)=crd(:,1)';
				POINT.Coordinate3(2,:)=crd(:,2)';
				POINT.Coordinate3(3,:)=crd(:,3)';
				
				if FileType==5	%VRML
					%Normals reorientation
					%calculating2points on orientation vector goingthrough the geometry center of the molecule
					X_l=mean(POINT.Coordinate3(1,:)); %X coordinate of the geometry center
					Y_l=mean(POINT.Coordinate3(2,:)); %Y coordinate of the geometry center
					Z_l=mean(POINT.Coordinate3(3,:)); %Z coordinate of the geometry center
					X_h=X_l+CrosNormal(1);
					Y_h=Y_l+CrosNormal(2);
					Z_h=Z_l+CrosNormal(3);
					%disp(['Final orientation line coordinates [X_l,Y_l,Z_l,X_h,Y_h,Z_h]: ',...
					%num2str([X_l,Y_l,Z_l,X_h,Y_h,Z_h])]);
					
					%____________ Find the rotation axis normal to the orientation line ([X_l,Y_l,Z_l],[X_h,Y_h,Z_h])
					%             and Z axis
					a_r=Y_l-Y_h;	%vector length in X direction
					b_r=X_h-X_l;	%vector length in Y direction
					c_r=0;	%vector length in Z direction
					AcosR=-acos((Z_h-Z_l)/((X_h-X_l)^2+(Y_h-Y_l)^2+(Z_h-Z_l)^2)^0.5);	%Rotation angle - angle of orientation line with Z axis
					disp(['Normals were rotated by ', num2str(fix(abs(AcosR/3.1415*180))),' degrees']);
					
					%===================== Reorientation of the protein
					crd(1:length(POINT.Normal(1,:)),1)=POINT.Normal(1,:)';
					crd(:,2)=POINT.Normal(2,:)';
					crd(:,3)=POINT.Normal(3,:)';
					crd=rotate_coordinates(crd,[X_l,Y_l,Z_l],[a_r,b_r,c_r],AcosR);
					%read transformed coordinates
					POINT.Normal(1,:)=crd(:,1)';
					POINT.Normal(2,:)=crd(:,2)';
					POINT.Normal(3,:)=crd(:,3)';
				end
			end	%Method of the calculation of slices crossection area
		end	%Type of the normal to the crossection plane {'X axis','Y axis','Z axis','Custom vector'}
		
		%Convert to polar coordinates if necessary
		switch CalcMethod	%Method of the calculation of slices crossection area
		case {2, 4, 5}	%'By closest-farest points (PDB, VRML, *.mat)', 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
			[POINT.Coordinate3(1,:),POINT.Coordinate3(2,:)]=cart2pol(POINT.Coordinate3(1,:),POINT.Coordinate3(2,:));
		end
		
		%Calculation minimal and maximal coordinates, crossection planes positions and contour sections (if necessary)
		%It is created by the first file coordinates (to minimize memory use)
		if FirstStructure==1;	%This is the first structure read in this set
			FirstStructure=0;
			
			%========= Calculating vertical bins
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%'By volumetric density crossection (*.mat)'
				MinZ=min(vMBinsZ);
				MaxZ=max(vMBinsZ);
			case 3	%'By surface crossection point (VRML, *.mat)'
				%------------ Remove doubled vertices
				if size(POINT.Coordinate3,2)>size(POINT.IndexedFaceSet,2)	%there are doubled vertices
%					POINT=VRML_remove_duplicate_vertices(POINT,0,'Absolute',0,0,0,0);
					POINT=VRML_remove_duplicate_vertices(POINT,0.05,'Absolute',0,0,0,0);
%					POINT=VRML_remove_duplicate_vertices(POINT,0.1,'Relative',0,0,0,0);
				end
				MinZ=min(POINT.Coordinate3(3,:));
				MaxZ=max(POINT.Coordinate3(3,:));
			case {2, 4, 5}	%'By closest-farest points (PDB, VRML, *.mat)', 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				MinZ=min(POINT.Coordinate3(3,:));
				MaxZ=max(POINT.Coordinate3(3,:));
			end
			deltaZ=MaxZ-MinZ;
			%increase boundaries 1% to include all points
			MinZ=MinZ-deltaZ/100;
			MaxZ=MaxZ+deltaZ/100;
			
			switch GridStepType	%Type of the calculation of slices grid steps - by the step length or number of steps{'Length, A','Steps'}
				% GridStep	- Length of the grid step (in Angstroms) or number of steps in the grid
			case 1	%'Length, A'
				BinsZ=MinZ:GridStep:MaxZ;	%bins boundaries
			case 2	%'Steps'
				BinsZ=MinZ:(MaxZ-MinZ)/GridStep:MaxZ;	%bins boundaries
			end
			MBinsZ=(BinsZ(1:(end-1))+BinsZ(2:end))/2;	%bins medians
			
			%=========== calculating angle position for circular profile
			MinT=-pi;
			MaxT=pi;
			BinsT=MinT:(MaxT-MinT)/SectNum:MaxT;	%Sector bins boundaries
			MBinsT=(BinsT(1:(end-1))+BinsT(2:end))/2;	%Sector bins medians
		end
		
		
		for zz=1:length(MBinsZ);	%================ Cycle through the slices
			ProgressBarLocal(zz,length(MBinsZ));%Set current value on the local progress bar

			% 		switch FileType	%initial file type {'*.pdb', '*.txt', '*.*','*.mat','*.wrl'}
			% 		case 1	%'*.pdb'
			% 		case 4	%'*.mat'
			% 		case 5	%'*.wrl'
			% 		end
			% 			switch CalcMethod	%Method of the calculation of slices crossection area
			% 			case 1	%'By volumetric density crossection (*.mat)'
			% 			case 2	%'By closest-farest points (PDB, VRML, *.mat)'
			% 			case 3	%'By surface crossection point (VRML, *.mat)'
			% 			case 4	%'By "umbrella touch"(PDB, VRML, *.mat)'
			%			case 5
			% 			end	%Method of the calculation of slices crossection area
			
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%'By volumetric density crossection (*.mat)'
				if zz==1; figure; set(gcf,'Visible','Off'); hold on; end;	%Temporal hidden image for contours
				%Define Z bin for the slice
				tvMBinsZ=abs(vMBinsZ-MBinsZ(zz));
				vNBinZ=find(tvMBinsZ==min(tvMBinsZ));
				%make a slice
				h = contourslice(permute(VolmData,[2 1 3]),[],[],[vNBinZ],[PlotContourLevel PlotContourLevel]);
				
				Xdata=get(h,'Xdata'); Ydata=get(h,'Ydata');	%Get contour coordinates data.
				
				if isempty(Xdata)	%No points at this level
					CrosProp(m,zz).Area={};	%Array with area data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Radius={};	%Array with radius data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Length={};	%Array with perimeter length data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordOrt={};	%Array with orthogonal contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordPol={};	%Array with polar contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
				else
% 					CrosProp(m,zz).CoordOrt{1}=[];	
					if ~iscell(Xdata)	%there is only one contour - convert addays to cell
						Xdata={Xdata};
						Ydata={Ydata};
					end	
						
					%Convert data into real coordinates and transfer them to the contours array
					for c=1:length(Xdata)	%Cycle through the contours in the current slice
						CrosProp(m,zz).CoordOrt{c}(1,:)=Ax*Xdata{c}(~isnan(Xdata{c}))+Bx;
						CrosProp(m,zz).CoordOrt{c}(2,:)=Ay*Ydata{c}(~isnan(Ydata{c}))+By;
						
					end
				end
					
				if zz==length(MBinsZ); hold off; close(gcf); end;	%Close Temporal hidden image for contours
			case 2	%'By closest-farest points (PDB, VRML, *.mat)'
				CurrentSlice=find(POINT.Coordinate3(3,:)>=BinsZ(zz)&POINT.Coordinate3(3,:)<BinsZ(zz+1));
				if isempty(CurrentSlice)	%No points at this level
					CrosProp(m,zz).Area={};	%Array with area data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Radius={};	%Array with radius data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Length={};	%Array with perimeter length data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordOrt={};	%Array with orthogonal contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordPol={};	%Array with polar contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
				else
					CrosProp(m,zz).CoordPol{1}=[];	
					CrosProp(m,zz).CoordPol{2}=[];	
					for tt=1:length(MBinsT)	%Cycle through the sectors
						CurrentSector=find(POINT.Coordinate3(1,CurrentSlice)>=BinsT(tt)&...
							POINT.Coordinate3(1,CurrentSlice)<BinsT(tt+1));
						if isempty(CurrentSector)	%No points in this sector
							% 							CrosProp(m,zz).CoordPol{1}(2,tt)=NaN;	%Distance to the closest point in the current sector
							% 							CrosProp(m,zz).CoordPol{2}(2,tt)=NaN;	%Distance to the farest point in the current sector
						else	%There are some points in this sector
							CrosProp(m,zz).CoordPol{1}(1,end+1)=MBinsT(tt);	%Angular position of the current sector for the closest contour
							CrosProp(m,zz).CoordPol{2}(1,end+1)=MBinsT(tt);	%Angular position of the current sector for the farest contour
							PointFar=max(POINT.Coordinate3(2,CurrentSlice(CurrentSector)));
							PointClose=min(POINT.Coordinate3(2,CurrentSlice(CurrentSector)));
							
							if VDWRadiusSource==1&FileType==1	%Include VDW data into PDB file
								switch VDWRadiusSource	%Option to include VDW radii for PDB file
								case 1
								case 2
								case 3
								end
							else
								CrosProp(m,zz).CoordPol{1}(2,end)=PointClose;	%Distance to the closest point in the current sector
								CrosProp(m,zz).CoordPol{2}(2,end)=PointFar;	%Distance to the farest point in the current sector
							end	%Include VDW data into PDB file
							
							%======= Block to select if a single point relates to outer or inner contour
							% 							if length(CurrentSector)==1&tt>1&...
							% 									~isnan(CrosProp(m,zz).CoordPol{1}(2,tt-1))&...
							% 									~isnan(CrosProp(m,zz).CoordPol{2}(2,tt-1))	%There is only one point in the sector
							% 								%This is not the first sector, so we are able to compare
							% 								if abs(PointClose-CrosProp(m,zz).CoordPol{1}(2,tt-1))<=...
							% 										abs(PointClose-CrosProp(m,zz).CoordPol{2}(2,tt-1)) %Closest point similar to previous inner circle
							% 									CrosProp(m,zz).CoordPol{2}(2,tt)=[];	%Remove Distance to the farest point in the current sector
							% 									CrosProp(m,zz).CoordPol{2}(1,tt)=[];	%Remove angle to the farest point in the current sector
							% 								else
							% 									CrosProp(m,zz).CoordPol{1}(2,tt)=[];	%Remove Distance to the closest point in the current sector
							% 									CrosProp(m,zz).CoordPol{1}(1,tt)=[];	%Remove angle to the closest point in the current sector
							% 								end
							% 							end
							
						end	%Check for the points in the current slice
					end	%Cycle through the sectors of the current slice
				end	%Check for the points in the current slice
			case 3	%'By surface crossection point (VRML, *.mat)'
				
				%------------ Find all the facets intersecting with the current crossection plane
				
				Edges=zeros(3,size(POINT.IndexedFaceSet,2));	%List of all possible Edges of facets crossected by
				dots=find((POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))<MBinsZ(zz))|...
					(POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))<MBinsZ(zz)));	%Crossection with the first edges of facets
				Edges(1,dots)=1;
				
				dots=find((POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:))<MBinsZ(zz))|...
					(POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(2,:))<MBinsZ(zz)));	%Crossection with the second edges of facets
				Edges(2,dots)=1;
				
				dots=find((POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))<MBinsZ(zz))|...
					(POINT.Coordinate3(3,POINT.IndexedFaceSet(1,:))>=MBinsZ(zz)&...
					POINT.Coordinate3(3,POINT.IndexedFaceSet(3,:))<MBinsZ(zz)));	%Crossection with the third edges of facets
				Edges(3,dots)=1;
				
				SegmentsNumbers=find(sum(Edges,1)==2);	%List of faces which are intersected with the plane
				if isempty(SegmentsNumbers)	%There are no crossected facets
					CrosProp(m,zz).Area={};	%Array with area data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Radius={};	%Array with radius data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Length={};	%Array with perimeter length data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordOrt={};	%Array with orthogonal contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordPol={};	%Array with polar contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
				else
					Segments=[];
					Segments.inf=Edges(:,SegmentsNumbers);	%Select only crossected facets
					Segments.inf(2,:)=2*Segments.inf(2,:);	%Assign value 2 to the cells indicating intercestion of edge 2
					Segments.inf(3,:)=3*Segments.inf(3,:);	%Assign value 3 to the cells indicating intercestion of edge 3
					Segments.inf=sort(Segments.inf,1);
					Segments.inf=Segments.inf([2 3 1],:);	%1st and 2nd rows are indices of crossected edges making this segment
					Segments.inf(3,:)=SegmentsNumbers;	%3rd row has indices of facets these edges belows to
					
					for sg=1:size(Segments.inf,2);	%Cycle through the list of intersected segments
						%Find indices for vertices flanking edges with crossection points
						Segments.Point1_a(sg)=POINT.IndexedFaceSet(Segments.inf(1,sg),Segments.inf(3,sg)); %Index of point 1 for the _a side of the intercestion segment
						Segments.Point2_a(sg)=POINT.IndexedFaceSet((rem(Segments.inf(1,sg),3)+1),Segments.inf(3,sg)); %Index of point 2 for the _a side of the intercestion segment
						Segments.Point1_b(sg)=POINT.IndexedFaceSet(Segments.inf(2,sg),Segments.inf(3,sg)); %Index of point 1 for the _b side of the intercestion segment
						Segments.Point2_b(sg)=POINT.IndexedFaceSet((rem(Segments.inf(2,sg),3)+1),Segments.inf(3,sg)); %Index of point 2 for the _b side of the intercestion segment
					end
					
% 					%Temporal test plotting%!!!
% 					Xtmp=POINT.Coordinate3(1,[Segments.Point1_a, Segments.Point2_a, Segments.Point1_b, Segments.Point2_b]);%!!!
% 					Ytmp=POINT.Coordinate3(2,[Segments.Point1_a, Segments.Point2_a, Segments.Point1_b, Segments.Point2_b]);%!!!
% 					Ztmp=POINT.Coordinate3(3,[Segments.Point1_a, Segments.Point2_a, Segments.Point1_b, Segments.Point2_b]);%!!!
% 					figure;%!!!
% 					plot3(Xtmp,Ytmp,Ztmp, '.');%!!!
% 					hold on;%!!!
% 					for pp=SegmentsNumbers	%!!!
% 						Xtmp=POINT.Coordinate3(1,[POINT.IndexedFaceSet(1,pp), POINT.IndexedFaceSet(2,pp),POINT.IndexedFaceSet(3,pp),POINT.IndexedFaceSet(1,pp)]);%!!!
% 						Ytmp=POINT.Coordinate3(2,[POINT.IndexedFaceSet(1,pp), POINT.IndexedFaceSet(2,pp),POINT.IndexedFaceSet(3,pp),POINT.IndexedFaceSet(1,pp)]);%!!!
% 						Ztmp=POINT.Coordinate3(3,[POINT.IndexedFaceSet(1,pp), POINT.IndexedFaceSet(2,pp),POINT.IndexedFaceSet(3,pp),POINT.IndexedFaceSet(1,pp)]);%!!!
% 						plot3(Xtmp,Ytmp,Ztmp, ':c');%!!!
% 
% 					end%!!!

					
					
					
					%------------ Remove duplicate points and Join points into the lines
					Segments.line=zeros(1,length(Segments.Point1_a(1,:)));	%Initialize array with line indexes for every crossection point. 
					%number of the line current segment belongs to
					%if point _b coincides with point _b of the other segment, this other segment will be inverted to make it point _a
					%if nothing is found to connect point _b of the current segment - this will be the last point in the line. Both _a and _b points of the segment will be included in the final line coordinates. For the rest of points only _a coordinate will be used
					
					Segments.line(1)=1;	%Line #1
					Line=[];
					Line{1}=1;
					
					ci=1;	%Current index checked for joint point
					
					OneDirection=1;	%Flag for the new line beginning, only one direction ofline grows was checked
% 					%Temporal test plotting%!!!
% 					Xtmp=POINT.Coordinate3(1,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 					Ytmp=POINT.Coordinate3(2,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 					Ztmp=POINT.Coordinate3(3,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 					plot3(Xtmp,Ytmp,Ztmp, 'm:o');%!!!
% 					%Temporal test plotting%!!!
% 					Xtmp=POINT.Coordinate3(1,[Segments.Point1_b(ci), Segments.Point2_b(ci)]);%!!!
% 					Ytmp=POINT.Coordinate3(2,[Segments.Point1_b(ci), Segments.Point2_b(ci)]);%!!!
% 					Ztmp=POINT.Coordinate3(3,[Segments.Point1_b(ci), Segments.Point2_b(ci)]);%!!!
% 					plot3(Xtmp,Ytmp,Ztmp, 'r:o');%!!!
					
					while ~isempty(ci)	%while there are some points without lines assigned
						JoinPoint=find(Segments.line(:)==0&(...
							(Segments.Point1_a(:)==Segments.Point1_b(ci)&...
							Segments.Point2_a(:)==Segments.Point2_b(ci))...
							|...
							(Segments.Point1_a(:)==Segments.Point2_b(ci)&...
							Segments.Point2_a(:)==Segments.Point1_b(ci))));	%Find all the unassigned edges _a wic coincide with edge _b of the current segment
						
						if isempty(JoinPoint)	%No coinciding edges
							%one more attempt to find cinciding edge - in _b edges of unassigned points
							JoinPoint=find(Segments.line(:)==0&(...
								(Segments.Point1_b(:)==Segments.Point1_b(ci)&...
								Segments.Point2_b(:)==Segments.Point2_b(ci))...
								|...
								(Segments.Point1_b(:)==Segments.Point2_b(ci)&...
								Segments.Point2_b(:)==Segments.Point1_b(ci))));	%Find all the unassigned edges _a wic coincide with edge _b of the current segment
							if ~isempty(JoinPoint)	%There are some coinciding edges after second attempt
								%Swap _a and _b of the joint point segment 
								sw=JoinPoint(1);
								[Segments.Point1_a(sw) Segments.Point1_b(sw)]=swap(Segments.Point1_a(sw),Segments.Point1_b(sw));
								[Segments.Point2_a(sw) Segments.Point2_b(sw)]=swap(Segments.Point2_a(sw),Segments.Point2_b(sw));
								[Segments.inf(1,sw) Segments.inf(2,sw)]=swap(Segments.inf(1,sw),Segments.inf(2,sw));
							end	%There are some coinciding edges after second attempt
						end	%No coinciding edges
						
						if ~isempty(JoinPoint)	%There are some coinciding edges after 2 attempts
							JoinPoint=JoinPoint(1);	%for the case of more than 1 point found - souldn't happen
							Segments.line(JoinPoint)=Segments.line(ci);	%Mark found point as found - assign current line number to the newfound point
							Line{end}(end+1)=JoinPoint; %add new point index to the list of indexex of segments of the current line
							ci=JoinPoint;	%Take found point as the last point in the current line
							
% 							%Temporal test plotting%!!!
% 							Xtmp=POINT.Coordinate3(1,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 							Ytmp=POINT.Coordinate3(2,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 							Ztmp=POINT.Coordinate3(3,[Segments.Point1_a(ci), Segments.Point2_a(ci)]);%!!!
% 							plot3(Xtmp,Ytmp,Ztmp, 'o-k');%!!!
							
						else	%There are no coinciding edges after 2 attempts
							if OneDirection==1	%only one direction of line grows was checked in the new line
								%Swap _a and _b of the new line segments,and the line direction
								sw=find(Segments.line==length(Line));	%points assigned to the current line
								[Segments.Point1_a(sw) Segments.Point1_b(sw)]=swap(Segments.Point1_a(sw),Segments.Point1_b(sw));
								[Segments.Point2_a(sw) Segments.Point2_b(sw)]=swap(Segments.Point2_a(sw),Segments.Point2_b(sw));
								[Segments.inf(1,sw) Segments.inf(2,sw)]=swap(Segments.inf(1,sw),Segments.inf(2,sw));
								OneDirection=0;	%Both direction of line grows were checked in the new line
								Line{end}=Line{end}(end:-1:1);	%Inversion of the current line indices
								ci=Line{end}(end); %the last segment in the line - it was the first before inversion
								%Now one more attempt to find coinciding edges to make joint point
							else	%%There are no at all coinciding edges
								OneDirection=1;	%only one direction of line grows was checked in the new line
								ci=find(Segments.line(:)==0);	%find segments with unassignedlines
								if ~isempty(ci)	%there are some segments unassigned to lines
									ci=ci(1);	%the first of unassigned segments
									Line{end+1}(1)=ci;	%new line initialization
									Segments.line(ci)=length(Line);
								end	%there are some segments unassigned to lines
							end	%If this is the first segment in the new line
						end	%There are some coinciding edges after 2 attempts
						
					end	%while there are some points without lines assigned

					
					%------------ Find crossection points for all the segments in the lines
					for c=1:length(Line)	%Cycle through the contour lines of the current slice
						%Find coordinates of the points 1 and 2 of the current facet edge
						X1_a=POINT.Coordinate3(1,Segments.Point1_a(Line{c}(:)));
						Y1_a=POINT.Coordinate3(2,Segments.Point1_a(Line{c}(:)));
						Z1_a=POINT.Coordinate3(3,Segments.Point1_a(Line{c}(:)));
						
						X2_a=POINT.Coordinate3(1,Segments.Point2_a(Line{c}(:)));
						Y2_a=POINT.Coordinate3(2,Segments.Point2_a(Line{c}(:)));
						Z2_a=POINT.Coordinate3(3,Segments.Point2_a(Line{c}(:)));
						
						%----- Find intersection point for the first edge of current two for the current facet
						Zz_a=MBinsZ(zz);
						Xz_a=(Zz_a-Z1_a).*(X2_a-X1_a)./(Z2_a-Z1_a)+X1_a;	%X coordinates of the crossection point
						Yz_a=(Zz_a-Z1_a).*(Y2_a-Y1_a)./(Z2_a-Z1_a)+Y1_a;	%Y coordinates of the crossection point
						
						%------------ Separate and save contours
						%transfer data to the contours array
						
% 						%Temporal test plotting%!!!
% 						Xtmp=Xz_a;%!!!
% 						Ytmp=Yz_a;%!!!
% 						Ztmp=Zz_a*ones(size(Xtmp));%!!!
% 						plot3(Xtmp,Ytmp,Ztmp, '*-g');%!!!
							
						CrosProp(m,zz).CoordOrt{c}(1,:)=Xz_a;
						CrosProp(m,zz).CoordOrt{c}(2,:)=Yz_a;
					end	%Cycle through the contour lines of the current slice
				end 	%There are no crossected facets
				
			case 4	%'By "umbrella touch"(PDB, VRML, *.mat)'
			case 5	%'By histogram method(PDB, VRML, *.mat)'
				CurrentSlice=find(POINT.Coordinate3(3,:)>=BinsZ(zz)&POINT.Coordinate3(3,:)<BinsZ(zz+1));
				if isempty(CurrentSlice)	%No points at this level
					CrosProp(m,zz).Area={};	%Array with area data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Radius={};	%Array with radius data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).Length={};	%Array with perimeter length data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordOrt={};	%Array with orthogonal contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
					CrosProp(m,zz).CoordPol={};	%Array with polar contour coordinates data about calculated crossectons: columns - separate contours; rows - slices
				else
% 					figure
% 					hist(POINT.Coordinate3(2,CurrentSlice),round(length(CurrentSlice)^0.5));%!!!
					CrosProp(m,zz).CoordPol{1}=[];	
					CrosProp(m,zz).CoordPol{2}=[];	
					for tt=1:length(MBinsT)	%Cycle through the sectors
						CurrentSector=find(POINT.Coordinate3(1,CurrentSlice)>=BinsT(tt)&...
							POINT.Coordinate3(1,CurrentSlice)<BinsT(tt+1));
						if isempty(CurrentSector)	%No points in this sector
							% 							CrosProp(m,zz).CoordPol{1}(2,tt)=NaN;	%Distance to the closest point in the current sector
							% 							CrosProp(m,zz).CoordPol{2}(2,tt)=NaN;	%Distance to the farest point in the current sector
						else	%There are some points in this sector
							CrosProp(m,zz).CoordPol{1}(1,end+1)=MBinsT(tt);	%Angular position of the current sector for the closest contour
							CrosProp(m,zz).CoordPol{2}(1,end+1)=MBinsT(tt);	%Angular position of the current sector for the farest contour
							[CurrentSectorHist,CurrentSectorBins]=hist(POINT.Coordinate3(2,CurrentSlice(CurrentSector)),round(length(CurrentSector)^0.5));%!!!
							NormFitOut=multi_normal_fit(CurrentSectorHist,CurrentSectorBins,2);
							PointFar=NormFitOut(1,2);
							PointClose=NormFitOut(1,1);
							
							if VDWRadiusSource==1&FileType==1	%Include VDW data into PDB file
								switch VDWRadiusSource	%Option to include VDW radii for PDB file
								case 1
								case 2
								case 3
								end
							else
								CrosProp(m,zz).CoordPol{1}(2,end)=PointClose;	%Distance to the closest point in the current sector
								CrosProp(m,zz).CoordPol{2}(2,end)=PointFar;	%Distance to the farest point in the current sector
							end	%Include VDW data into PDB file
							
							%======= Block to select if a single point relates to outer or inner contour
							% 							if length(CurrentSector)==1&tt>1&...
							% 									~isnan(CrosProp(m,zz).CoordPol{1}(2,tt-1))&...
							% 									~isnan(CrosProp(m,zz).CoordPol{2}(2,tt-1))	%There is only one point in the sector
							% 								%This is not the first sector, so we are able to compare
							% 								if abs(PointClose-CrosProp(m,zz).CoordPol{1}(2,tt-1))<=...
							% 										abs(PointClose-CrosProp(m,zz).CoordPol{2}(2,tt-1)) %Closest point similar to previous inner circle
							% 									CrosProp(m,zz).CoordPol{2}(2,tt)=[];	%Remove Distance to the farest point in the current sector
							% 									CrosProp(m,zz).CoordPol{2}(1,tt)=[];	%Remove angle to the farest point in the current sector
							% 								else
							% 									CrosProp(m,zz).CoordPol{1}(2,tt)=[];	%Remove Distance to the closest point in the current sector
							% 									CrosProp(m,zz).CoordPol{1}(1,tt)=[];	%Remove angle to the closest point in the current sector
							% 								end
							% 							end
							
						end	%Check for the points in the current slice
					end	%Cycle through the sectors of the current slice
				end	%Check for the points in the current slice
			end	%Method of the calculation of slices crossection area

			%---------------- Calculate the area, etc - all the values and cartez. coord.
			%Select if contour data are in cartesian or polar coordinates
			switch CalcMethod	%Method of the calculation of slices crossection area
			case 1	%'By volumetric density crossection (*.mat)'
				for c=1:length(CrosProp(m,zz).CoordOrt)	%Cycle through the contours in the current slice
					CurveNodes=size(CrosProp(m,zz).CoordOrt{c}(1,:),2);
					if CurveNodes>=1	%There is at least one point in the countour
						%calculation of the polar coordinates
						[CrosProp(m,zz).CoordPol{c}(1,1:CurveNodes),CrosProp(m,zz).CoordPol{c}(2,1:CurveNodes)]=...
							pol2cart(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:));
						%if CurveNodes>=2	%There is at least two points in the countour
						%Perimeter length calculation
						CrosProp(m,zz).Length{c}=abs(PermtrLength(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,0,10));
						%area calculation
						CrosProp(m,zz).Area{c}=abs(CurveArea(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,0,10));
						%Radius calculation
						CrosProp(m,zz).Radius{c}=(CrosProp(m,zz).Area{c}/pi)^0.5;
						%end	%Check for the sectors in the current contour
					end	%Check for the points in the current contour
				end		%Cycle through the contours in the current slice
			case 3	%'By surface crossection point (VRML, *.mat)'
				for c=1:length(CrosProp(m,zz).CoordOrt)	%Cycle through the contours in the current slice
					CurveNodes=size(CrosProp(m,zz).CoordOrt{c}(1,:),2);
					if CurveNodes>=1	%There is at least one point in the countour
						%calculation of the polar coordinates
						[CrosProp(m,zz).CoordPol{c}(1,1:CurveNodes),CrosProp(m,zz).CoordPol{c}(2,1:CurveNodes)]=...
							pol2cart(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:));
						%if CurveNodes>=2	%There is at least two points in the countour
						%Perimeter length calculation
						CrosProp(m,zz).Length{c}=abs(PermtrLength(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,1,10));
						%area calculation
						CrosProp(m,zz).Area{c}=abs(CurveArea(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,1,10));
						%Radius calculation
						CrosProp(m,zz).Radius{c}=(CrosProp(m,zz).Area{c}/pi)^0.5;
						%end	%Check for the sectors in the current contour
					end	%Check for the points in the current contour
				end		%Cycle through the contours in the current slice
			case {2, 4, 5}	%'By closest-farest points (PDB, VRML, *.mat)', 'By "umbrella touch"(PDB, VRML, *.mat)' 'By histogram method(PDB, VRML, *.mat)'
				for c=1:length(CrosProp(m,zz).CoordPol)	%Cycle through the contours in the current slice
					CurveNodes=size(CrosProp(m,zz).CoordPol{c}(1,:),2);
					if CurveNodes>=1	%There is at least one point in the countour
						%calculation of the orthogonal coordinates
						[CrosProp(m,zz).CoordOrt{c}(1,1:CurveNodes),CrosProp(m,zz).CoordOrt{c}(2,1:CurveNodes)]=...
							pol2cart(CrosProp(m,zz).CoordPol{c}(1,:),CrosProp(m,zz).CoordPol{c}(2,:));
						%if CurveNodes>=2	%There is at least two points in the countour
						%Perimeter length calculation
						CrosProp(m,zz).Length{c}=abs(PermtrLength(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,1,10));
						%area calculation
						CrosProp(m,zz).Area{c}=abs(CurveArea(CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(2,:),1,1,10));
						%Radius calculation
						CrosProp(m,zz).Radius{c}=(CrosProp(m,zz).Area{c}/pi)^0.5;
						%end	%Check for the sectors in the current contour
					end	%Check for the points in the current contour
				end		%Cycle through the contours in the current slice
			end
			%Finish of the areas etc. calculation for the current slice
			
		end	%=============== Cycle through the slices
		ProgressBarGlobal((m-1+0.6),length(s));%Set current value on the global progress bar
		
		%=== Surface saving and visualisation
		if SaveSurf>1|PlotSurf==1|PrintSurf==1|ImageSurf==1	%Save surface or Visualize surface
			switch FileType	%initial file type {'*.pdb', '*.txt', '*.*','*.mat','*.wrl'}
			case 1	%'*.pdb'
				if SaveSurf>1	%Save surface
				end	%Save surface
				
				ProgressBarGlobal((m-1+0.9),length(s));%Set current value on the global progress bar
				
				if PlotSurf==1|PrintSurf==1|ImageSurf==1	%Visualize and print surface
					figure; hold on;
					%set(gca,'Color',[0.5, 0.5, 0.5]);
					Nzz=length(POINT.Coordinate3(1,:));
					for zz=1:Nzz
						p=plot3(ATOM.x(zz),ATOM.y(zz)',ATOM.z(zz)','o',...
							'Color', [0 0 0],...
							'MarkerFaceColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)]);
					end
					%plot3([POINT.Coordinate3(1,:),POINT.Coordinate3(2,:),POINT.Coordinate3(3,:),'.');
					axis equal; axis vis3d;
					title(['Atom''s positions of the ',s{m}]);
					xlabel('X, A'); ylabel('Y, A'); zlabel('Z, A');
					hold off;
					%Create VRML surface
					switch CalcMethod	%Method of the calculation of slices crossection area
					case 1	%'By volumetric density crossection (*.mat)'
					case 2	%'By closest-farest points (PDB, VRML, *.mat)'
					case 3	%'By surface crossection point (VRML, *.mat)'
					case 4	%'By "umbrella touch"(PDB, VRML, *.mat)'
					end	%Method of the calculation of slices crossection area
					if PrintSurf==1	%Print surface
						print;
					end
					if ImageSurf==1	%Print surface
                        tstr=['print -dpng ''Atom''s_positions_of_the_',s{m},'.png'''];
                        eval(tstr);
					end
					if PlotSurf==0	%Don't plot surface
						close;
					end

				end	%Visualize surface
			case {4, 5, 6} %'*.mat' %'*.wrl'
				%Convert from polar coordinates if necessary
				switch CalcMethod	%Method of the calculation of slices crossection area
				case 1	%'By volumetric density crossection (*.mat)'
					%Create patch surface from the volumetric data
					Surface=isosurface(permute(VolmData,[2 1 3]),PlotContourLevel);
					POINT.Coordinate3=Surface.vertices';
					POINT.IndexedFaceSet(1:3,:)=Surface.faces';
					clear Surface;
					
					%Convert surface coordinates from volumetric data to their real values
					vMinX=min(vMBinsX); vMaxX=max(vMBinsX);
					vMinY=min(vMBinsY); vMaxY=max(vMBinsY);
					vMinZ=min(vMBinsZ); vMaxZ=max(vMBinsZ);
					Ax=(vMaxX-vMinX)/(size(VolmData,1)-1); Bx=vMinX-Ax;
					Ay=(vMaxY-vMinY)/(size(VolmData,2)-1); By=vMinY-Ay;
					Az=(vMaxZ-vMinZ)/(size(VolmData,3)-1); Bz=vMinZ-Az;
					POINT.Coordinate3(1,:)=Ax*POINT.Coordinate3(1,:)+Bx;
					POINT.Coordinate3(2,:)=Ay*POINT.Coordinate3(2,:)+By;
					POINT.Coordinate3(3,:)=Az*POINT.Coordinate3(3,:)+Bz;
				case {2, 4}	%'By closest-farest points (PDB, VRML, *.mat)', 'By "umbrella touch"(PDB, VRML, *.mat)'
					[POINT.Coordinate3(1,:),POINT.Coordinate3(2,:)]=pol2cart(POINT.Coordinate3(1,:),POINT.Coordinate3(2,:));
				end
				
				disp SaveSurf
				switch SaveSurf	%Save surface?
                case 1  %Don't save
                case 2  %Save VRML as a *.mat file
					tmp1=POINT.Coordinate3; tmp2=POINT.IndexedFaceSet;
					saveFileName=[s{m},'_VRML.mat'];
					tstr=['save ''',saveFileName,''' tmp1 tmp2;'];
					eval(tstr);
					if ZIPoutput==1
						zip([saveFileName,'.zip'],saveFileName);
						delete(saveFileName);
					end
                case 3  %Save triangle coordinates in plain text
                    tmp1=[];
                    for cc=1:length(POINT.IndexedFaceSet)
                        tmp1(cc,1:9)=[POINT.Coordinate3(:,POINT.IndexedFaceSet(1,cc))',POINT.Coordinate3(:,POINT.IndexedFaceSet(2,cc))',POINT.Coordinate3(:,POINT.IndexedFaceSet(3,cc))'];
                    end
					saveFileName=[s{m},'_triangles.txt'];
					tstr=['save ''',saveFileName,''' -ASCII tmp1;'];
					eval(tstr);
					if ZIPoutput==1
						zip([saveFileName,'.zip'],saveFileName);
						delete(saveFileName);
					end
				end	%Save surface
				
				ProgressBarGlobal((m-1+0.9),length(s));%Set current value on the global progress bar

				if PlotSurf==1|PrintSurf==1|ImageSurf==1	%Visualize or print surface
					figure
					Surface.vertices=POINT.Coordinate3'; Surface.faces=POINT.IndexedFaceSet(1:3,:)';
					p = patch(Surface);
					set(p,'FaceColor',[0.8 1 1],'EdgeColor','none');
					daspect([1 1 1]); view(3); axis tight; camlight; lighting gouraud
					if CalcMethod==1	%Volumetric density crossection
						title(['Surface of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
					else
						title(['Surface of the ',s{m}]);
					end
					xlabel('X, A'); ylabel('Y, A'); zlabel('Z, A');
					
					if PrintSurf==1	%Print surface
						print;
					end
					if ImageSurf==1	%Print surface
                        tstr=['print -dpng ''',s{m},'_VRML.png'''];
                        eval(tstr);
					end
					if PlotSurf==0	%Don't plot surface
						close;
					end

				end	%Visualize surface
			end	%initial file type
		end	%Save surface or Visualize surface
		
		%=====  save and plot calculated contours
		if SaveCrosContr==1 %save in file the calculated crossections contours
			fh=fopen([s{m},'_crs_contours.txt'],'w');
			if CalcMethod==1	%Volumetric density crossection
				fprintf(fh,'%s\n',['Crossection contours of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				fprintf(fh,'%s\n',['Crossection contours of the ',s{m}]);
			end
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				fprintf(fh,'%s\n','');
				fprintf(fh,'%s','Slice # '); fprintf(fh,'%g',zz); fprintf(fh,'%s',' of '); fprintf(fh,'%g\t',Nzz); fprintf(fh,'%s\t','Slice position, A:'); fprintf(fh,'%16.14g\n',MBinsZ(zz));
				if length(CrosProp(m,zz).CoordOrt)>0	%There are contours in the current slice
					%Sort contours by length
					ContSize=[]; SortContSize=[];
					for c=1:length(CrosProp(m,zz).CoordOrt)	%Cycle through the contours in the current slice
						ContSize(c)=size(CrosProp(m,zz).CoordOrt{c},2);
					end	%Cycle through the contours in the current slice
					[ContSize,SortContSize]=sort(ContSize);
					SortContSize=SortContSize(end:-1:1);	%Resorting from max to min
					
					%for c=1:length(CrosProp(m,zz).CoordOrt)	%Cycle through the contours in the current slice
					for c=SortContSize	%Cycle through the contours in the current slice
						fprintf(fh,'%s\n','');
						fprintf(fh,'%s','Contour # '); fprintf(fh,'%g',c); fprintf(fh,'%s',' of '); fprintf(fh,'%g\n',length(CrosProp(m,zz).CoordOrt));
						fprintf(fh,'%s\t','"Xn (in slice plane), A"'); fprintf(fh,'%s\t','"Yn (in slice plane), A"'); fprintf(fh,'%s\n','"Zn (along slice normal), A"');
						for p=1:length(CrosProp(m,zz).CoordOrt{c}(1,:))	%cycle through the points of the current contour
							fprintf(fh,'%16.14g\t',CrosProp(m,zz).CoordOrt{c}(1,p));
							fprintf(fh,'%16.14g\t',CrosProp(m,zz).CoordOrt{c}(2,p));
							fprintf(fh,'%16.14g\n',MBinsZ(zz));
						end
					end	%Cycle through the contours in the current slice
				else
					fprintf(fh,'%s\n','(There are no contours in this slice)');
				end	
			end	%================ Cycle through the slices
			fclose(fh);
			
			if ZIPoutput==1
				zip([s{m},'_crs_contours.txt.zip'],[s{m},'_crs_contours.txt']);
				delete([s{m},'_crs_contours.txt']);
			end
		end %save in file the calculated crossections contours
		
		if PlotCrosContr==1|PrintCrosContr==1|ImageCrosContr==1	%plot or print calculated contours
			figure; hold on;
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				for c=1:length(CrosProp(m,zz).CoordOrt)	%Cycle through the contours in the current slice
					plot3([CrosProp(m,zz).CoordOrt{c}(1,:),CrosProp(m,zz).CoordOrt{c}(1,1)],...
						[CrosProp(m,zz).CoordOrt{c}(2,:),CrosProp(m,zz).CoordOrt{c}(2,1)],...
						ones(size([CrosProp(m,zz).CoordOrt{c}(2,:),CrosProp(m,zz).CoordOrt{c}(2,1)]))*MBinsZ(zz),'-',...
						'Color', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)]);
					axis equal; axis vis3d;
				end		%Cycle through the contours in the current slice
			end	%================ Cycle through the slices
			if CalcMethod==1	%Volumetric density crossection
				title(['Crossection contours of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				title(['Crossection contours of the ',s{m}]);
			end
			xlabel('Xn (in slice plane), A');
			ylabel('Yn (in slice plane), A');
			zlabel('Zn (along slice normal), A');
			hold off;
					
			if PrintCrosContr==1	%Print contours
				print;
			end
            if ImageCrosContr==1	%Print contours
                tstr=['print -dpng ''',s{m},'_crs_contours.png'''];
                eval(tstr);
            end
			if PlotCrosContr==0	%Don't plot contours
				close;
			end

		end	%plot calculated contours
		
		%=====  save and plot calculated Areas
		if SaveCrosAreas==1 %save in file the calculated crossections areas
			fh=fopen([s{m},'_crs_areas.txt'],'w');
			if CalcMethod==1	%Volumetric density crossection
				fprintf(fh,'%s\n',['Crossection areas of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				fprintf(fh,'%s\n',['Crossection areas of the ',s{m}]);
			end
			fprintf(fh,'%s\t','"Slice position, A"'); fprintf(fh,'%s\n','"Crossection area, A^2"');
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				if length(CrosProp(m,zz).Area)~=0	%There are contours in the current slice
					%Sort contours by area
					ContSize=[]; SortContSize=[];
					for c=1:length(CrosProp(m,zz).Area)	%Cycle through the contours in the current slice
						ContSize(c)=CrosProp(m,zz).Area{c};
					end	%Cycle through the contours in the current slice
					[ContSize,SortContSize]=sort(ContSize);
					SortContSize=SortContSize(end:-1:1);	%Resorting from max to min
					
					fprintf(fh,'%16.14g\t',MBinsZ(zz));
					%fprintf(fh,'%16.14g\t', CrosProp(m,zz).Area{1:end-1});fprintf(fh,'%16.14g\n', CrosProp(m,zz).Area{end});
					fprintf(fh,'%16.14g\t', CrosProp(m,zz).Area{SortContSize(1:end-1)});fprintf(fh,'%16.14g\n', CrosProp(m,zz).Area{SortContSize(end)});
				end	
			end	%================ Cycle through the slices
			fclose(fh);
		end %save in file the calculated crossections contours
		if PlotCrosAreas==1|PrintCrosAreas==1|ImageCrosAreas==1	%plot or print crossections areas
			figure; hold on;
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				for c=1:length(CrosProp(m,zz).Area)	%Cycle through the contours in the current slice
					plot(MBinsZ(zz),CrosProp(m,zz).Area{c},'o',...
						'MarkerFaceColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)],...
						'MarkerEdgeColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)]);
					set(gca,'XGrid','on'); set(gca,'YGrid','on'); 
				end		%Cycle through the contours in the current slice
			end	%================ Cycle through the slices
			if CalcMethod==1	%Volumetric density crossection
				title(['Crossection areas of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				title(['Crossection areas of the ',s{m}]);
			end
			xlabel('Slice position, A');
			ylabel('Crossection area, A^2');
			t=ylim; ylim([0 t(2)]);
			hold off;
			
			if PrintCrosAreas==1	%Print Areas
				print;
			end
            if ImageCrosAreas==1	%Print Areas
                tstr=['print -dpng ''',s{m},'_crs_areas.png'''];
                eval(tstr);
            end
			if PlotCrosAreas==0	%Don't plot Areas
				close;
			end

		end	%plot calculated areas
		
		%=====  save and plot calculated Radii
		if SaveCrosRadii==1 %save in file the calculated crossections radii
			fh=fopen([s{m},'_crs_radii.txt'],'w');
			if CalcMethod==1	%Volumetric density crossection
				fprintf(fh,'%s\n',['Average radii of the crossections of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				fprintf(fh,'%s\n',['Average radii of the crossections of the ',s{m}]);
			end
			fprintf(fh,'%s\t','"Slice position, A"'); fprintf(fh,'%s\n','"Crossection radius, A"');
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				if length(CrosProp(m,zz).Radius)~=0	%There are contours in the current slice
					%Sort contours by radius
					ContSize=[]; SortContSize=[];
					for c=1:length(CrosProp(m,zz).Radius)	%Cycle through the contours in the current slice
						ContSize(c)=CrosProp(m,zz).Radius{c};
					end	%Cycle through the contours in the current slice
					[ContSize,SortContSize]=sort(ContSize);
					SortContSize=SortContSize(end:-1:1);	%Resorting from max to min
					
					fprintf(fh,'%16.14g\t',MBinsZ(zz));
					fprintf(fh,'%16.14g\t', CrosProp(m,zz).Radius{SortContSize(1:end-1)});fprintf(fh,'%16.14g\n', CrosProp(m,zz).Radius{SortContSize(end)});
				end	
			end	%================ Cycle through the slices
			fclose(fh);
		end %save in file the calculated crossections radii
		if PlotCrosRadii==1|PrintCrosRadii==1|ImageCrosRadii==1	%plot or print calculated radii
			figure; hold on;
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				for c=1:length(CrosProp(m,zz).Radius)	%Cycle through the contours in the current slice
					plot(MBinsZ(zz),CrosProp(m,zz).Radius{c},'*',...
						'MarkerFaceColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)],...
						'MarkerEdgeColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)]);
					set(gca,'XGrid','on'); set(gca,'YGrid','on'); 
				end		%Cycle through the contours in the current slice
			end	%================ Cycle through the slices
			if CalcMethod==1	%Volumetric density crossection
				title(['Average radii of the crossections of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				title(['Average radii of the crossections of the ',s{m}]);
			end
			xlabel('Slice position, A');
			ylabel('Crossection radius, A');
			t=ylim; ylim([0 t(2)]);
			hold off;
			
			if PrintCrosRadii==1	%Print Radii
				print;
			end
            if ImageCrosRadii==1	%Print Radii
                tstr=['print -dpng ''',s{m},'_crs_radii.png'''];
                eval(tstr);
            end
			if PlotCrosRadii==0	%Don't plot Radii
				close;
			end

		end	%plot calculated radii
		
%=====  save and plot calculated perimeters
		if SaveCrosPerim==1 %save in file the calculated crossections perimeters
			fh=fopen([s{m},'_crs_perim.txt'],'w');
			if CalcMethod==1	%Volumetric density crossection
				fprintf(fh,'%s\n',['Average perimeter length of the crossections of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				fprintf(fh,'%s\n',['Average perimeter length of the crossections of the ',s{m}]);
			end
			fprintf(fh,'%s\t','"Slice position, A"'); fprintf(fh,'%s\n','"Crossection perimeter length, A"');
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				if length(CrosProp(m,zz).Length)~=0	%There are contours in the current slice
					%Sort contours by perimeter Length
					ContSize=[]; SortContSize=[];
					for c=1:length(CrosProp(m,zz).Length)	%Cycle through the contours in the current slice
						ContSize(c)=CrosProp(m,zz).Length{c};
					end	%Cycle through the contours in the current slice
					[ContSize,SortContSize]=sort(ContSize);
					SortContSize=SortContSize(end:-1:1);	%Resorting from max to min
					
					fprintf(fh,'%16.14g\t',MBinsZ(zz));
					fprintf(fh,'%16.14g\t', CrosProp(m,zz).Length{SortContSize(1:end-1)});fprintf(fh,'%16.14g\n', CrosProp(m,zz).Length{SortContSize(end)});
				end	
			end	%================ Cycle through the slices
			fclose(fh);
		end %save in file the calculated crossections radii
		if PlotCrosPerim==1|PrintCrosPerim==1|ImageCrosPerim==1	%plot or print calculated perineter
			figure; hold on;
			Nzz=length(MBinsZ);	%Number of slices
			for zz=1:Nzz;	%================ Cycle through the slices
				for c=1:length(CrosProp(m,zz).Length)	%Cycle through the contours in the current slice
					plot(MBinsZ(zz),CrosProp(m,zz).Length{c},'o',...
						'MarkerFaceColor', 'white',...
						'MarkerEdgeColor', [(1-zz/Nzz),(1-2*abs(zz-Nzz/2)/Nzz),(zz/Nzz)]);
					set(gca,'XGrid','on'); set(gca,'YGrid','on'); 
				end		%Cycle through the contours in the current slice
			end	%================ Cycle through the slices
			if CalcMethod==1	%Volumetric density crossection
				title(['Average perimeter length of the crossections of the ',s{m},' at the p=',num2str(PlotContourLevel),' level']);
			else
				title(['Average perimeter length of the crossections of the ',s{m}]);
			end
			xlabel('Slice position, A');
			ylabel('Crossection perimeter length, A');
			t=ylim; ylim([0 t(2)]);
			hold off;
			
			if PrintCrosPerim==1	%Print Perim
				print;
			end
            if ImageCrosPerim==1	%Print Perim
                tstr=['print -dpng ''',s{m},'_crs_perim.png'''];
                eval(tstr);
            end
			if PlotCrosPerim==0	%Don't plot Perim
				close;
			end

		end	%plot calculated perimeters		
		
		%toc
		SndNp(2);
		POINT=[];	%Clearing POINT array
		ProgressBarGlobal((m),length(s));%Set current value on the global progress bar
	end	%========================Cycle through the input files
	
end	%End of calculation in case there are some files


