function writePDBfull(fname1,ATOM,Fields,OrigPDB)
%this function d=reads PDB file into structure array
%input:
%fname1 - filename for PDB file
%OrigPDB - Use missing information from original file stored in ATOM.pdb field) <1>, from the original
%file on HDD <2>, or don't use it, just add END at the end <0>, default
%Fields	- Vector indicating fields of PDB to read (default - all)
%Output:
%ATOM - structure array with the fields corresponding to ones in ATOM record of PDB file

switch nargin
case 2
	OrigPDB=0;	%Don't use information from original file
	Fields=ones(1,15);
case 3
	Fields=ones(1,15);
end
if length(Fields)==0; Fields=ones(1,15); end

%==== Fill PDB file by the spaces
switch OrigPDB
case 0
	A(1:length(ATOM.line),1:80)=' ';	%Space filled PDB file
case 1
	if size(ATOM.pdb)==0;
		OrigPDB=0;
		numlines=length(ATOM);
		A(1:numlines,1:80)=' ';	%Space filled PDB file
	else
		A=ATOM.pdb;
	end
case 2	%Use missing information from the original file on HDD <2>
	A=textread(fname1,'%s','delimiter','\n','whitespace','');
	numlines=length(A)
	t(1:80)=' '; t(1:length(A{1}));
	A{1}=t;
	A=char(A);
end

%==== calculate number of lines in PDB file
numlines=size(A,1);	%number of lines in the PDB file being prepared

%fname1=[fname1,'_new.pdb'];	%new filename

%  1 -  6        Record name     &quot;ATOM  &quot;
%  7 - 11        Integer         serial        Atom serial number.
% 13 - 16        Atom            name          Atom name.
% 17             Character       altLoc        Alternate location indicator.
% 18 - 20        Residue name    resName       Residue name.
% 22             Character       chainID       Chain identifier.
% 23 - 26        Integer         resSeq        Residue sequence number.
% 27             AChar           iCode         Code for insertion of residues.
% 31 - 38        Real(8.3)       x             Orthogonal coordinates for X in
%                                              Angstroms.
% 39 - 46        Real(8.3)       y             Orthogonal coordinates for Y in
%                                              Angstroms.
% 47 - 54        Real(8.3)       z             Orthogonal coordinates for Z in
%                                              Angstroms.
% 55 - 60        Real(6.2)       occupancy     Occupancy.
% 61 - 66        Real(6.2)       tempFactor    Temperature factor.
% 73 - 76        LString(4)      segID         Segment identifier, left-justified.
% 77 - 78        LString(2)      element       Element symbol, right-justified.
% 79 - 80        LString(2)      charge        Charge on the atom.


%=========== ATOM array filling out


if OrigPDB==0	%Don't use original PDB
	for i = 1 : numlines
		if Fields(1)==1; A(i,7:11)=sprintf('%5i',ATOM.index(i)); end	%        Atom serial number.
% 		if Fields(2)==1; A(i,13:16)=sprintf('%4s',ATOM.name{i}); end	%          Atom name.
		if Fields(2)==1; tt=ATOM.name{i}; for ii=1:(4-length(ATOM.name{i})); tt=[tt ' ']; end; A(i,13:16)=sprintf('%4s',tt); end	%          Atom name.
		if Fields(3)==1; A(i,17)=sprintf('%c',ATOM.altloc{i}); end	%        Alternate location indicator.
% 		if Fields(4)==1; A(i,18:20)=sprintf('%3s',ATOM.resname{i}); end	%       Residue name.
		if Fields(4)==1; tt=ATOM.resname{i}; for ii=1:(3-length(ATOM.resname{i})); tt=[tt ' ']; end;  A(i,18:20)=sprintf('%3s',tt); end	%          Atom name.
		if Fields(5)==1; A(i,22)=sprintf('%c',ATOM.chain{i}); end	%       Chain identifier.
		if Fields(6)==1; A(i,23:26)=sprintf('%4i',ATOM.resid(i)); end	%        Residue sequence number.
		if Fields(7)==1; A(i,27)=sprintf('%c',ATOM.icode{i}); end	%         Code for insertion of residues.
		if Fields(8)==1; A(i,31:38)=sprintf('%8.3f',ATOM.x(i)); end	%             Orthogonal coordinates for X in Angstroms.
		if Fields(9)==1; A(i,39:46)=sprintf('%8.3f',ATOM.y(i)); end	%             Orthogonal coordinates for Y in Angstroms.
		if Fields(10)==1; A(i,47:54)=sprintf('%8.3f',ATOM.z(i)); end	%             Orthogonal coordinates for Z in Angstroms.
% 		if Fields(11)==1; A(i,55:60)=sprintf('%6.2f',ATOM.occupancy(i)); end	%     Occupancy.
% 		if Fields(12)==1; A(i,61:66)=sprintf('%6.2f',ATOM.beta(i)); end	%    Temperature factor.
			if Fields(11)==1; 	%     Occupancy.
				a=ATOM.occupancy(i);	%Temporal variable
				if ((a<1000&a>=0.01)|(a>-100&a<=-0.01))
					b=sprintf('%6.2f',a);
				elseif ((a<10000&a>=1000)|(a>-1000&a<=-100))
					b=sprintf('%6.1f',a);
				elseif ((a<1000000&a>=10000)|(a>-100000&a<=-1000))
					b=sprintf('%6.0f',a);
				elseif (a<0.01&a>0)
					b=sprintf('%6.4f',a);
				elseif (a==0)
					b=sprintf('%6i',a);
				elseif (a<0&a>-0.01)
					b=sprintf('%6.3f',a);
				else
					b='000000';
				end
				A(i,55:60)=b;
			end
			if Fields(12)==1; 	%    Temperature factor.
				a=ATOM.beta(i);	%Temporal variable
				if ((a<1000&a>=0.01)|(a>-100&a<=-0.01))
					b=sprintf('%6.2f',a);
				elseif ((a<10000&a>=1000)|(a>-1000&a<=-100))
					b=sprintf('%6.1f',a);
				elseif ((a<1000000&a>=10000)|(a>-100000&a<=-1000))
					b=sprintf('%6.0f',a);
				elseif (a<0.01&a>0)
					b=sprintf('%6.4f',a);
				elseif (a==0)
					b=sprintf('%6i',a);
				elseif (a<0&a>-0.01)
					b=sprintf('%6.3f',a);
				else
					b='000000';
				end
				A(i,61:66)=b;
			end
% 		if Fields(13)==1; A(i,73:76)=sprintf('%4s',ATOM.segname{i}); end	%         Segment identifier, left-justified.
		if Fields(13)==1; tt=ATOM.segname{i}; for ii=1:(4-length(ATOM.segname{i})); tt=[tt ' ']; end;  A(i,73:76)=sprintf('%4s',tt); end	%          Atom name.
		if Fields(14)==1; A(i,77:78)=sprintf('%2s',ATOM.element{i}); end	%       Element symbol, right-justified.
		if Fields(15)==1; A(i,79:80)=sprintf('%2s',ATOM.charge{i}); end	%        Charge on the atom.
	end
	A(end+1,1:3)='END';
else	%use original PDB
	for i = 1 : numlines
		if (A(i,1:4)=='ATOM' | A(i,1:4)=='HETA')
			n=find(ATOM.line==i);
			if Fields(1)==1; A(i,7:11)=sprintf('%5i',ATOM.index(n)); end	%        Atom serial number.
% 			if Fields(2)==1; A(i,13:16)=sprintf('%4s',ATOM.name{n}); end	%          Atom name.
			if Fields(2)==1; tt=ATOM.name{n}; for ii=1:(4-length(ATOM.name{n})); tt=[tt ' ']; end; A(i,13:16)=sprintf('%4s',tt); end	%          Atom name.
			if Fields(3)==1; A(i,17)=sprintf('%c',ATOM.altloc{n}); end	%        Alternate location indicator.
% 			if Fields(4)==1; A(i,18:20)=sprintf('%3s',ATOM.resname{n}); end	%       Residue name.
			if Fields(4)==1; tt=ATOM.resname{n}; for ii=1:(3-length(ATOM.resname{n})); tt=[tt ' ']; end;  A(i,18:20)=sprintf('%3s',tt); end	%          Atom name.
			if Fields(5)==1; A(i,22)=sprintf('%c',ATOM.chain{n}); end	%       Chain identifier.
			if Fields(6)==1; A(i,23:26)=sprintf('%4i',ATOM.resid(n)); end	%        Residue sequence number.
			if Fields(7)==1; A(i,27)=sprintf('%c',ATOM.icode{n}); end	%         Code for insertion of residues.
			if Fields(8)==1; A(i,31:38)=sprintf('%8.3f',ATOM.x(n)); end	%             Orthogonal coordinates for X in Angstroms.
			if Fields(9)==1; A(i,39:46)=sprintf('%8.3f',ATOM.y(n)); end	%             Orthogonal coordinates for Y in Angstroms.
			if Fields(10)==1; A(i,47:54)=sprintf('%8.3f',ATOM.z(n)); end	%             Orthogonal coordinates for Z in Angstroms.
% 			if Fields(11)==1; A(i,55:60)=sprintf('%6.2f',ATOM.occupancy(n)); end	%     Occupancy.
% 			if Fields(12)==1; A(i,61:66)=sprintf('%6.2f',ATOM.beta(n)); end	%    Temperature factor.
			if Fields(11)==1; 	%     Occupancy.
				a=ATOM.occupancy(n);	%Temporal variable
				if ((a<1000&a>=0.01)|(a>-100&a<=-0.01))
					b=sprintf('%6.2f',a);
				elseif ((a<10000&a>=1000)|(a>-1000&a<=-100))
					b=sprintf('%6.1f',a);
				elseif ((a<1000000&a>=10000)|(a>-100000&a<=-1000))
					b=sprintf('%6.0f',a);
				elseif (a<0.01&a>0)
					b=sprintf('%6.4f',a);
				elseif (a==0)
					b=sprintf('%6i',a);
				elseif (a<0&a>-0.01)
					b=sprintf('%6.3f',a);
				else
					b='000000';
				end
				A(i,55:60)=b;
			end
			if Fields(12)==1; 	%    Temperature factor.
				a=ATOM.beta(n);	%Temporal variable
				if ((a<1000&a>=0.01)|(a>-100&a<=-0.01))
					b=sprintf('%6.2f',a);
				elseif ((a<10000&a>=1000)|(a>-1000&a<=-100))
					b=sprintf('%6.1f',a);
				elseif ((a<1000000&a>=10000)|(a>-100000&a<=-1000))
					b=sprintf('%6.0f',a);
				elseif (a<0.01&a>0)
					b=sprintf('%6.4f',a);
				elseif (a==0)
					b=sprintf('%6i',a);
				elseif (a<0&a>-0.01)
					b=sprintf('%6.3f',a);
				else
					b='000000';
				end
				A(i,61:66)=b;
			end
% 			if Fields(13)==1; A(i,73:76)=sprintf('%4s',ATOM.segname{n}); end	%         Segment identifier, left-justified.
			if Fields(13)==1; tt=ATOM.segname{n}; for ii=1:(4-length(ATOM.segname{n})); tt=[tt ' ']; end;  A(i,73:76)=sprintf('%4s',tt); end	%          Atom name.
			if Fields(14)==1; A(i,77:78)=sprintf('%2s',ATOM.element{n}); end	%       Element symbol, right-justified.
			if Fields(15)==1; A(i,79:80)=sprintf('%2s',ATOM.charge{n}); end	%        Charge on the atom.
		end
	end
end
%disp([num2str(size(ATOM.index)), ' atoms structure read']);
%plot(ATOM.x)%!


fid = fopen (fname1,'w');
for i=1:size(A,1)
	fprintf(fid,'%s\n',A(i,:));
end
fclose (fid);
